* Generate the statistics for Paper
cd "R:\OfficeData\"
use OfficeN, clear
local loglocation="R:\OfficeData\"
qui collapse woffice lcoffice floorj,by(officej)
log using "`loglocation'PaperStats.txt", replace text
**************************************************************************
**************************************************************************
* * Table 1 Summary Stats  * *
**************************************************************************
sum woffice lcoffice floor
qui{
	use FacultyChar, clear
}
sum female_d join_years phd_years

qui{
use network_matrix, clear
collapse (sum) fin_coauthors_d (sum) fin_colls_d (sum) fin_samedept (sum) fin_social (sum) fin_friend_d (sum) fin_lunches_d (sum) fin_clustersame, by(officei)
merge office using FacultyChar
keep if _merge==3
drop _merge
}
* NUMBER OF LINKS IN COAUTHORSHIP NETWORK
sum  fin_coauthors_d
* NUMBER OF LINKS IN SOCIAL NETWORKS
* (N.B. SOCIAL HERE REFERS TO THE UNIONED VARIABLE LUNCHES AND FRIEND, WHILE 
* FRIDEND REFERS TO THE ATTENDS SOCIAL EVENTS SURVEY QUESTION)
sum  fin_colls_d fin_friend_d fin_lunches_d fin_social if  survey_respondent_d==1
* NUMBER OF LINKS IN INSTITUTIONAL NETWORKS
sum  fin_samedept fin_clustersame

**********************************************************************************
**********************************************************************************
* * Table 2 Network Correlations  * *
**********************************************************************************
qui{
	use network_matrix, clear
	merge officei using FacultyChar
	keep if _merge==3
	drop _merge
	preserve
		collapse survey_respondent_d (max) fin_social, by(officei)
		gen ext_survey_respondent_i=survey_respondent_d==1
		replace ext_survey_respondent_i=(1==1) if fin_social==1
		drop fin_social survey_respondent_d
		sort officei
		save ExtSurveyRespondents_i, replace
		rename ext_survey_respondent_i ext_survey_respondent_j
		rename officei officej
		sort officej
		save ExtSurveyRespondents_j, replace
		use FacultyChar, clear
		rename officei officej
		rename survey_respondent_d survey_respondent_j
		keep officej survey_respondent_j
		sort officej
		save SurveyRespondents_j, replace
	restore
	rename survey_respondent_d survey_respondent_i
	sort officei 
	merge officei using ExtSurveyRespondents_i
	keep if _merge==3
	drop _merge
	sort officej 
	merge officej using ExtSurveyRespondents_j
	keep if _merge==3
	drop _merge
	sort officej
	merge officej using SurveyRespondents_j
	keep if _merge==3
	drop _merge
	cap erase "ExtSurveyRespondents_i"
	cap erase "ExtSurveyRespondents_j"	
	cap erase "SurveyRespondents_j"
	
}
* * FULL SAMPLE * *
corr fin_samedept fin_clustersame fin_coauthors_d fin_social if officei<officej
* * EXT SURVEY * *
corr fin_samedept fin_clustersame fin_coauthors_d fin_social if officei<officej & ext_survey_respondent_i==1 & ext_survey_respondent_j==1
* * ONLY SURVEY * *
corr fin_samedept fin_clustersame fin_coauthors_d fin_social if officei<officej & survey_respondent_i==1 & survey_respondent_j==1
qui use OfficeN, clear
***************************************************************************************
***************************************************************************************
* * Table 3 Conditional Logistic Regressions * *
**************************************************************************************

qui {
 * PENALIZE refers to whether the office is available
local CL1_list="officechosen lcoffice woffice highestav if penalize==0"
local CL2_list="officechosen lcoffice woffice highestav nd_samedept dept_floor if penalize==0"
local CL3_list="officechosen lcoffice woffice highestav nd_samedept nd_coauthor if penalize==0"
local CL4_list="officechosen lcoffice woffice highestav nd_samedept  nd_coauth_nsocial nd_social_ncoauth nd_coauthsocial if penalize==0 & extsurvey_i==1"

	forvalues i=1/4 { 
		clogit `CL`i'_list' , group(officei)
		mfx, predict(pu0) at(zero)
		est store CLnew`i', title("CL(`i')")
	}
	
}
***************************************************************************************
* * Table 3 Conditional Logistic Regressions, decomposed networks * *
***************************************************************************************
estout CLnew1 CLnew2 CLnew3 CLnew4 , margin style(smcl) stats(N)  cells(b(star fmt(3)) se(par) ) starlevels(* 0.10 ** 0.05 *** 0.01)
log close
view "`loglocation'PaperStats.txt"



