(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    332600,       8201]
NotebookOptionsPosition[    322985,       7903]
NotebookOutlinePosition[    323418,       7921]
CellTagsIndexPosition[    323375,       7918]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

The following is uses much of Fox & Santiago' s code to estimate the pairwise \
stability equations. It also requires the MatchEstimation library available \
from Jeremy Fox' s website.\
\>", "Text",
 CellChangeTimes->{{3.523016659331128*^9, 3.523016769642438*^9}}],

Cell[CellGroupData[{

Cell["Set - Up", "Subtitle",
 CellChangeTimes->{{3.4906407308842587`*^9, 3.4906407330763845`*^9}}],

Cell[CellGroupData[{

Cell["Initialize", "Section",
 CellChangeTimes->{{3.4906406991914463`*^9, 3.4906407015875835`*^9}, {
  3.49495879010078*^9, 3.4949587933109636`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.499432145335294*^9, 3.4994321487985*^9}, {
  3.4994322374437337`*^9, 3.4994322422783117`*^9}, {3.4994323879469967`*^9, 
  3.499432398601815*^9}}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "]"}]], "Input",
 CellChangeTimes->{{3.448985830671875*^9, 3.44898583990625*^9}, {
   3.448986985625*^9, 3.4467508964767437`*^9}, 3.4473546627526097`*^9, {
   3.4535022439698515`*^9, 3.453502244770852*^9}, {3.4900978151030765`*^9, 
   3.490097816838176*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Combinatorica`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{
      RowBox[{"\"\<FileName\>\"", "/.", 
       RowBox[{"NotebookInformation", "[", 
        RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ",", 
      RowBox[{"{", "1", "}"}], ",", "FrontEnd`FileName"}], "]"}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Needs", "[", 
   RowBox[{"\"\<MatchEstimation`\>\"", ",", 
    RowBox[{"StringJoin", "[", 
     RowBox[{
      RowBox[{"ToFileName", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{
         RowBox[{"\"\<FileName\>\"", "/.", 
          RowBox[{"NotebookInformation", "[", 
           RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ",", 
         RowBox[{"{", "1", "}"}], ",", "FrontEnd`FileName"}], "]"}], "]"}], 
      ",", "\"\<MatchEstimation\\MatchEstimation.m\>\""}], "]"}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.446731709557744*^9, 3.4467317237477436`*^9}, 
   3.495727397844399*^9, 3.4957274602949705`*^9, 3.4957275295759335`*^9, {
   3.498218930721752*^9, 3.498218938704209*^9}},
 EmphasizeSyntaxErrors->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial setup", "Section",
 CellChangeTimes->{{3.4906406208579655`*^9, 3.490640625603237*^9}}],

Cell[CellGroupData[{

Cell["Importing Code", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.490640601504859*^9, 3.4906406037609878`*^9}, {3.4949588243577394`*^9, 
  3.4949588255878096`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numNests", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numMatches", "=", "75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Grouping", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "1"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "19"}]}], ",", "1", ",", 
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "20"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "30"}]}], ",", "2", ",", 
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "31"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "41"}]}], ",", "3", ",", 
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "41"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "75"}]}], ",", "4"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "75"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GroupingTenure", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "1"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "30"}]}], ",", "1", ",", 
       RowBox[{
        RowBox[{"i", "\[GreaterEqual]", "31"}], " ", "&&", " ", 
        RowBox[{"i", "\[LessEqual]", " ", "75"}]}], ",", "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "75"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.448985234859375*^9, 3.44898523528125*^9}, {
   3.448987603984375*^9, 3.4489876069375*^9}, {3.448994162265625*^9, 
   3.44899416890625*^9}, 3.449047402390625*^9, {3.449055075328125*^9, 
   3.449055079546875*^9}, {3.44913742271875*^9, 3.449137424421875*^9}, {
   3.449140202171875*^9, 3.449140204859375*^9}, {3.449153031296875*^9, 
   3.44915303503125*^9}, {3.449323328796875*^9, 3.449323350421875*^9}, {
   3.44932526025*^9, 3.44932526278125*^9}, 3.4520056571952868`*^9, {
   3.4906204776494474`*^9, 3.4906205320015564`*^9}, {3.490620613074193*^9, 
   3.490620624626854*^9}, {3.490620754834302*^9, 3.4906208268354197`*^9}, 
   3.490621801394161*^9, {3.50109204690051*^9, 3.501092095525796*^9}, 
   3.523021583548092*^9, 3.5230216173516693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Enter the data (Requires you to run the Matlab file `Import.m'\
\>", "Subsection",
 CellChangeTimes->{{3.5230221125400457`*^9, 3.523022135799954*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"coauthN2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<n2_coauth.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"deptF2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<f2_dept.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"deptN2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<n2_dept.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"surveyR", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Import", "[", 
       RowBox[{"\"\<surveyed.csv\>\"", ",", "\"\<CSV\>\""}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"surveyExtR", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Import", "[", 
       RowBox[{"\"\<extsurvey.csv\>\"", ",", "\"\<CSV\>\""}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"officeFloor", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Import", "[", 
       RowBox[{"\"\<officefloor.csv\>\"", ",", "\"\<CSV\>\""}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"officeBlock", "=", " ", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Import", "[", 
       RowBox[{"\"\<officeblock.csv\>\"", ",", "\"\<CSV\>\""}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"scN2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<n2_CF.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"notscN2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<n2_CNF.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"snotcN2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<n2_NCF.csv\>\"", ",", "\"\<CSV\>\""}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.449323553265625*^9, 3.446738455904744*^9}, {
   3.446835153396744*^9, 3.446835181196744*^9}, {3.446835219501744*^9, 
   3.446835242973744*^9}, {3.446835273911744*^9, 3.4468352789507437`*^9}, {
   3.4468355735897436`*^9, 3.446835574054744*^9}, {3.4468357211487436`*^9, 
   3.446835736546744*^9}, {3.4468358324127436`*^9, 3.446835855083744*^9}, {
   3.446835906146744*^9, 3.4468360011807437`*^9}, {3.446836083343744*^9, 
   3.446836116046744*^9}, 3.446836185345744*^9, {3.446836306066744*^9, 
   3.446836307554744*^9}, {3.4473546725946097`*^9, 3.44735469514361*^9}, {
   3.452632634841729*^9, 3.452632743133729*^9}, {3.4526824298537292`*^9, 
   3.452682472934729*^9}, {3.4528902858667293`*^9, 3.452890314895729*^9}, {
   3.452906948237729*^9, 3.4529069799507294`*^9}, {3.4529070776987295`*^9, 
   3.452907173041729*^9}, {3.452907958253729*^9, 3.4529079792737293`*^9}, {
   3.4529455795247293`*^9, 3.452945632487729*^9}, {3.4530876056827292`*^9, 
   3.453087624446729*^9}, {3.4531473347147293`*^9, 3.4531473642197294`*^9}, {
   3.453728191582301*^9, 3.453728201004301*^9}, {3.454081578928301*^9, 
   3.4540816043333015`*^9}, {3.480423378374323*^9, 3.48042349546202*^9}, {
   3.480423552369275*^9, 3.48042355297831*^9}, {3.4805250160095778`*^9, 
   3.4805250329575467`*^9}, {3.480525094870088*^9, 3.480525104754653*^9}, {
   3.4818799871791606`*^9, 3.4818800372730255`*^9}, {3.4819804307552047`*^9, 
   3.4819804376575994`*^9}, {3.4819805594845676`*^9, 
   3.4819806016239777`*^9}, {3.494959104860783*^9, 3.4949591619840508`*^9}, {
   3.4954013555557117`*^9, 3.495401362358101*^9}, {3.495402278510502*^9, 
   3.4954022909602137`*^9}, {3.49540235698599*^9, 3.495402357112997*^9}, {
   3.4956252198990197`*^9, 3.4956252212740984`*^9}, {3.4956266502028284`*^9, 
   3.495626682891698*^9}, {3.495633361478691*^9, 3.495633386075098*^9}, {
   3.49571772562918*^9, 3.4957177689656587`*^9}, {3.500764811273674*^9, 
   3.500764813551278*^9}, {3.5015896717179174`*^9, 3.501589716152459*^9}, {
   3.5040999595685883`*^9, 3.5040999626057625`*^9}, {3.5045303082724113`*^9, 
   3.5045303578102446`*^9}, 3.5045304155315466`*^9, {3.5045317094705553`*^9, 
   3.5045317449425845`*^9}, {3.504531797276578*^9, 3.5045317986996593`*^9}, {
   3.504532331600139*^9, 3.50453237497362*^9}, {3.516525191090392*^9, 
   3.5165252038861237`*^9}, {3.51653205333189*^9, 3.5165320643795214`*^9}, {
   3.5168718094350133`*^9, 3.5168718275760508`*^9}, {3.5177393933687425`*^9, 
   3.5177394885941887`*^9}, {3.5177727423006444`*^9, 3.517772774983514*^9}, {
   3.5230165699410152`*^9, 3.523016570802065*^9}, {3.5230171145861673`*^9, 
   3.5230171743465853`*^9}, {3.5230172455956607`*^9, 
   3.5230172484138217`*^9}, {3.523021553833782*^9, 3.523021573819924*^9}, {
   3.5230219149019346`*^9, 3.5230219174603395`*^9}, 3.52302200468243*^9, {
   3.5230220373319554`*^9, 3.5230220443207674`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Total", "[", "surveyExtR", "]"}]], "Input",
 CellChangeTimes->{{3.500764817342085*^9, 3.5007648295413065`*^9}}],

Cell[BoxData["54"], "Output",
 CellChangeTimes->{3.504522932145521*^9, 3.504530432261503*^9, 
  3.5165252997226057`*^9, 3.523022052339182*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate the Outcome Variables", "Subsection",
 CellChangeTimes->{{3.5230221508851805`*^9, 3.5230221583575935`*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"outcome", ",", "outcome2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outcome", "=", 
   RowBox[{"{", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Boole", "[", 
       RowBox[{"i", "\[Equal]", "j"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "numMatches"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "10", ",", "10"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "46", ",", "46"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "52", ",", "52"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outcome2", "=", "outcome"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"outcome2", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{"surveyExtR", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome2", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "10", ",", "10"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome2", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "46", ",", "46"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome2", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "52", ",", "52"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outcome3", "=", "outcome"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"outcome3", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{"surveyR", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome3", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "10", ",", "10"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome3", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "46", ",", "46"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome3", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "52", ",", "52"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outcome4", "=", "outcome"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"outcome4", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{"Boole", "[", 
      RowBox[{"i", ">=", "31"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome4", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "10", ",", "10"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome4", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "46", ",", "46"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome4", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "52", ",", "52"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outcome5", "=", "outcome"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"outcome5", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Boole", "[", 
       RowBox[{"i", "\[GreaterEqual]", "31"}], "]"}], "*", 
      RowBox[{"surveyExtR", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome5", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "10", ",", "10"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome5", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "46", ",", "46"}], "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"outcome5", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "52", ",", "52"}], "]"}], "]"}], "=", "0"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4954024006584883`*^9, 3.495402408898959*^9}, {
  3.4954025221264353`*^9, 3.495402545893795*^9}, {3.495633423411234*^9, 
  3.4956334262263947`*^9}, {3.4958185507668705`*^9, 3.495818628840336*^9}, {
  3.5012388474282627`*^9, 3.5012388949459467`*^9}, {3.501244536305294*^9, 
  3.501244545904843*^9}, {3.523022060903597*^9, 3.523022061496398*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mate", " ", "=", " ", 
   RowBox[{"matchIndexMatrix", "[", 
    RowBox[{"outcome", " ", ",", " ", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mate2", "=", 
   RowBox[{"matchIndexMatrix", "[", 
    RowBox[{"outcome2", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mate3", "=", 
   RowBox[{"matchIndexMatrix", "[", 
    RowBox[{"outcome3", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mate4", "=", 
   RowBox[{"matchIndexMatrix", "[", 
    RowBox[{"outcome4", ",", "1"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4529072006417294`*^9, 3.452907221531729*^9}, {
   3.452907265161729*^9, 3.4529072683077292`*^9}, {3.476638864866985*^9, 
   3.476638882851013*^9}, {3.49540256556592*^9, 3.4954025711342382`*^9}, {
   3.4958186325735493`*^9, 3.495818640479002*^9}, {3.501238900390356*^9, 
   3.501238904477563*^9}, {3.5012390120709524`*^9, 3.5012390122113523`*^9}, 
   3.5230166174977355`*^9, {3.5230220879131413`*^9, 3.523022088271942*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ap", "=", " ", 
   RowBox[{"allPairsInequalityList", "[", "mate", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ap2", "=", 
   RowBox[{"allPairsInequalityList", "[", "mate2", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ap3", "=", 
   RowBox[{"allPairsInequalityList", "[", "mate3", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ap4", "=", 
    RowBox[{"allPairsInequalityList", "[", "mate4", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"at", "=", " ", 
   RowBox[{"allTripsInequalityList", "[", "mate", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"at2", "=", 
   RowBox[{"allTripsInequalityList", "[", "mate2", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"at3", "=", 
   RowBox[{"allTripsInequalityList", "[", "mate3", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.448989637015625*^9, 3.44898969490625*^9}, {
   3.449323593875*^9, 3.44932359959375*^9}, {3.452907274821729*^9, 
   3.4529072987877293`*^9}, {3.4662542093265657`*^9, 3.466254228286566*^9}, {
   3.4904473613717628`*^9, 3.4904473951286936`*^9}, {3.490620858010203*^9, 
   3.490620877330308*^9}, {3.4906226244502373`*^9, 3.4906226256183043`*^9}, {
   3.4906237346737385`*^9, 3.490623742098163*^9}, {3.495402576734559*^9, 
   3.4954026177589054`*^9}, {3.495727824422798*^9, 3.495727849451229*^9}, {
   3.4958186474404*^9, 3.4958186530087185`*^9}, 3.5010921813727465`*^9, {
   3.5012389636640673`*^9, 3.501238969404877*^9}, {3.5012390086233463`*^9, 
   3.501239009668548*^9}, 3.5230168237715335`*^9, {3.523022177620688*^9, 
   3.5230222080594196`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"apGroup", "=", 
   RowBox[{"allPairsInequalityListSameType", "[", 
    RowBox[{"mate", ",", "GroupingTenure"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"apGroup2", "=", 
   RowBox[{"allPairsInequalityListSameType", "[", 
    RowBox[{"mate2", ",", "GroupingTenure"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5010629159765477`*^9, 3.501062947254337*^9}, 
   3.5010792110263653`*^9, 3.501092183899951*^9, {3.5010922491548653`*^9, 
   3.501092263850091*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5012389786712933`*^9, 3.501238981884899*^9}, {
  3.5012448560515823`*^9, 3.501244885046241*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pre-computing Code", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
   3.490640562736641*^9, 3.4906405676319213`*^9}, 3.495633396585699*^9, 
   3.495633690887532*^9, {3.5230222198998404`*^9, 3.5230222214442425`*^9}}],

Cell[CellGroupData[{

Cell["precomputeCovariates", "Subsubsection",
 CellChangeTimes->{{3.495726705481798*^9, 3.4957267464651423`*^9}, 
   3.4957268077456474`*^9, {3.4958184838370423`*^9, 3.495818487660261*^9}, {
   3.501073285777666*^9, 3.5010732878507853`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"precomputeCovariates", "[", 
     RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArray", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"markets", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], " ", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"groups", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], " ", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"individuals", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"Flatten", "[", "groups", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dataMap", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
       " ", ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.44803127328125*^9, 3.44803476028125*^9, 3.44803516059375*^9, {
   3.44803550703125*^9, 3.448035585015625*^9}, {3.44803570865625*^9, 
   3.4480357261875*^9}, {3.44803579503125*^9, 3.44803582075*^9}, {
   3.44803610865625*^9, 3.448036138921875*^9}, {3.448125037484375*^9, 
   3.4481251889375*^9}, {3.448193820859375*^9, 3.448193845125*^9}, 
   3.448210785703125*^9, {3.44821345071875*^9, 3.4482134603125*^9}, {
   3.448213936046875*^9, 3.448213943578125*^9}, 3.44821406575*^9, {
   3.448214336359375*^9, 3.448214345921875*^9}, {3.44827493125*^9, 
   3.44827494459375*^9}, {3.448275704265625*^9, 3.448275716109375*^9}, {
   3.44828163778125*^9, 3.448281641890625*^9}, {3.4482819005*^9, 
   3.4482819213125*^9}, {3.448285065265625*^9, 3.44828507509375*^9}, {
   3.448619089484375*^9, 3.448619198234375*^9}, {3.448905846515625*^9, 
   3.448905879125*^9}, {3.448906792171875*^9, 3.448906859*^9}, {
   3.448906912953125*^9, 3.448906977421875*^9}, {3.4489070749375*^9, 
   3.44890707840625*^9}, 3.448984610296875*^9, {3.448984714015625*^9, 
   3.448984726671875*^9}, {3.4489849956875*^9, 3.44898501296875*^9}, {
   3.448985361*^9, 3.448985390375*^9}, {3.448985421921875*^9, 
   3.448985431140625*^9}, {3.44898558846875*^9, 3.44898562559375*^9}, {
   3.44898565815625*^9, 3.4489856589375*^9}, 3.44898587615625*^9, {
   3.448986017859375*^9, 3.448986028578125*^9}, {3.448989301109375*^9, 
   3.4489893140625*^9}, {3.448989898265625*^9, 3.448989907875*^9}, {
   3.448989942546875*^9, 3.448989972515625*^9}, {3.44899000884375*^9, 
   3.44899001196875*^9}, {3.448990051*^9, 3.44899005915625*^9}, {
   3.448990107734375*^9, 3.448990110328125*^9}, 3.44899045484375*^9, {
   3.448990497484375*^9, 3.448990579625*^9}, {3.44932366890625*^9, 
   3.4493236726875*^9}, {3.449323732109375*^9, 3.449323760515625*^9}, {
   3.44932379090625*^9, 3.449324015234375*^9}, {3.449324049109375*^9, 
   3.449324090953125*^9}, {3.449324122125*^9, 3.449324135359375*^9}, {
   3.449324167203125*^9, 3.449324284015625*^9}, {3.449324314875*^9, 
   3.44932441571875*^9}, {3.44932463953125*^9, 3.449324662015625*^9}, 
   3.4493247454375*^9, {3.449333643578125*^9, 3.44933365496875*^9}, {
   3.449343359953125*^9, 3.4467317570757437`*^9}, 3.446731799520744*^9, 
   3.4520069568012867`*^9, {3.452907345519729*^9, 3.4529073474437294`*^9}, {
   3.452907431006729*^9, 3.452907583211729*^9}, 3.458221335552*^9, {
   3.458221646226*^9, 3.458221658975*^9}, {3.4582217476619997`*^9, 
   3.458221871918*^9}, {3.458221906363*^9, 3.458221912876*^9}, {
   3.45822196526*^9, 3.458221988297*^9}, {3.45822205471*^9, 
   3.458222161767*^9}, {3.4662543236255655`*^9, 3.4662543400455656`*^9}, {
   3.4662544339135656`*^9, 3.4662545223155656`*^9}, {3.4662545527125654`*^9, 
   3.4662546942605658`*^9}, {3.4662547381415653`*^9, 
   3.4662547811015654`*^9}, {3.4662548381725655`*^9, 
   3.4662548633555655`*^9}, {3.466254902883566*^9, 3.4662549822285657`*^9}, {
   3.4662550147285657`*^9, 3.4662550559935656`*^9}, {3.4662552196915655`*^9, 
   3.4662552236095657`*^9}, {3.4662552617045655`*^9, 3.466255273864566*^9}, {
   3.4662553965115657`*^9, 3.4662554230855656`*^9}, {3.4662555675265656`*^9, 
   3.4662555695825653`*^9}, {3.4662556168485656`*^9, 
   3.4662556371515656`*^9}, {3.4662557194465656`*^9, 
   3.4662557400855656`*^9}, {3.4662558368795657`*^9, 3.466255857093566*^9}, {
   3.4766207112966595`*^9, 3.476620731861836*^9}, {3.476621070636213*^9, 
   3.47662112076108*^9}, {3.4766212184676685`*^9, 3.4766212323754635`*^9}, {
   3.476638998640636*^9, 3.476639008307189*^9}, {3.476639076480088*^9, 
   3.476639090344881*^9}, 3.4766393538739543`*^9, {3.4806978010870852`*^9, 
   3.480697805532339*^9}, {3.485451436565916*^9, 3.4854514536518936`*^9}, {
   3.4906223581670065`*^9, 3.4906223646823797`*^9}, {3.490622397158237*^9, 
   3.4906224323412495`*^9}, {3.4906224788669105`*^9, 3.490622521117327*^9}, {
   3.4906225785906143`*^9, 3.490622587032097*^9}, {3.490622685755744*^9, 
   3.490622686794803*^9}, {3.4906237682606597`*^9, 3.4906238296831727`*^9}, {
   3.490623875867814*^9, 3.490623890767667*^9}, {3.495402656509122*^9, 
   3.495402777765057*^9}, 3.495726667594631*^9, {3.4957267382196703`*^9, 
   3.4957267566607256`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariates2", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.499360884896834*^9, 3.499360885952894*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"precomputeCovariates2", "[", 
     RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"ap2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"ap2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"ap2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"ap2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArray2", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"markets2", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], " ", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", "1", "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", "1", ",", 
              RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"groups2", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], " ", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"individuals2", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"Flatten", "[", "groups2", "]"}], " ", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dataMap2", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets2", ",", " ", "groups2"}], "}"}], "]"}], "]"}]}], 
       ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{3.4957268278197956`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariates3", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.4957269528679476`*^9}}],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariates3", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"i1", ":=", 
       RowBox[{"ap3", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i2", ":=", 
       RowBox[{"ap3", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", ":=", 
       RowBox[{"ap3", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", ":=", 
       RowBox[{"ap3", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
        "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateObsExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "ap3", "]"}]}], "}"}]}], "]"}], ",", 
            " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateCFExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "ap3", "]"}]}], "}"}]}], "]"}], ",", 
            " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"dataArray3", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"cov", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"cf", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"markets3", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap3", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"groups3", "=", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap3", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"individuals3", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "groups3", "]"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataMap3", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"markets3", ",", " ", "groups3"}], "}"}], "]"}], "]"}]}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariates4", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.4957269528679476`*^9}, {3.495818667998576*^9, 
  3.495818669166643*^9}}],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariates4", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"i1", ":=", 
       RowBox[{"ap4", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i2", ":=", 
       RowBox[{"ap4", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", ":=", 
       RowBox[{"ap4", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", ":=", 
       RowBox[{"ap4", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
        "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateObsExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "ap4", "]"}]}], "}"}]}], "]"}], ",", 
            " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateCFExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "ap4", "]"}]}], "}"}]}], "]"}], ",", 
            " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"dataArray4", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"cov", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"cf", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"markets4", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap4", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"groups4", "=", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap4", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"individuals4", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "groups4", "]"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataMap4", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"markets4", ",", " ", "groups4"}], "}"}], "]"}], "]"}]}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input",
 CellChangeTimes->{{3.495818689548808*^9, 3.495818738929633*^9}, {
  3.4958187708494587`*^9, 3.495818781282055*^9}, {3.4958189200149903`*^9, 
  3.4958189201579986`*^9}}]
}, Closed]],

Cell[BoxData[Cell["precomputeCovariatesT", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.495726964580618*^9}}],

Cell[CellGroupData[{

Cell["precomputeCovariates Triples", "Subsubsection",
 CellChangeTimes->{{3.495726705481798*^9, 3.4957267464651423`*^9}, 
   3.4957268077456474`*^9, {3.4958184838370423`*^9, 3.495818487660261*^9}, {
   3.5010640105401535`*^9, 3.501064014437376*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"precomputeCovariatesTrips", "[", 
     RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3", ",", "a1",
         ",", "a2", ",", "a3"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i3", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"a1", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"a2", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"a3", ":=", 
        RowBox[{"ap", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"ineq", "[", 
           RowBox[{"[", "a", "]"}], "]"}], " ", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n", ",", "i", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "j", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "k", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "k", ",", "i"}], "}"}]}], "}"}]}], ";"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "p3"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], " ", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i3", ",", "p3"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "tripl1", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "triple"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "p3"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "a1", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "a2", ",", "p2"}], "]"}], "]"}]}],
              " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "a3", ",", "p3"}], "]"}], "]"}]}],
              " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArrayTrips", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"marketsTrips", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"groupsTrips", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "p2"}], "]"}], 
                  "]"}], "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}], ",", "Null"}], 
              "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"individualsTrips", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"Flatten", "[", "groupsTrips", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dataMapTrips", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"marketsTrips", ",", " ", "groupsTrips"}], "}"}], "]"}], 
         "]"}]}], " ", ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.44803127328125*^9, 3.44803476028125*^9, 3.44803516059375*^9, {
   3.44803550703125*^9, 3.448035585015625*^9}, {3.44803570865625*^9, 
   3.4480357261875*^9}, {3.44803579503125*^9, 3.44803582075*^9}, {
   3.44803610865625*^9, 3.448036138921875*^9}, {3.448125037484375*^9, 
   3.4481251889375*^9}, {3.448193820859375*^9, 3.448193845125*^9}, 
   3.448210785703125*^9, {3.44821345071875*^9, 3.4482134603125*^9}, {
   3.448213936046875*^9, 3.448213943578125*^9}, 3.44821406575*^9, {
   3.448214336359375*^9, 3.448214345921875*^9}, {3.44827493125*^9, 
   3.44827494459375*^9}, {3.448275704265625*^9, 3.448275716109375*^9}, {
   3.44828163778125*^9, 3.448281641890625*^9}, {3.4482819005*^9, 
   3.4482819213125*^9}, {3.448285065265625*^9, 3.44828507509375*^9}, {
   3.448619089484375*^9, 3.448619198234375*^9}, {3.448905846515625*^9, 
   3.448905879125*^9}, {3.448906792171875*^9, 3.448906859*^9}, {
   3.448906912953125*^9, 3.448906977421875*^9}, {3.4489070749375*^9, 
   3.44890707840625*^9}, 3.448984610296875*^9, {3.448984714015625*^9, 
   3.448984726671875*^9}, {3.4489849956875*^9, 3.44898501296875*^9}, {
   3.448985361*^9, 3.448985390375*^9}, {3.448985421921875*^9, 
   3.448985431140625*^9}, {3.44898558846875*^9, 3.44898562559375*^9}, {
   3.44898565815625*^9, 3.4489856589375*^9}, 3.44898587615625*^9, {
   3.448986017859375*^9, 3.448986028578125*^9}, {3.448989301109375*^9, 
   3.4489893140625*^9}, {3.448989898265625*^9, 3.448989907875*^9}, {
   3.448989942546875*^9, 3.448989972515625*^9}, {3.44899000884375*^9, 
   3.44899001196875*^9}, {3.448990051*^9, 3.44899005915625*^9}, {
   3.448990107734375*^9, 3.448990110328125*^9}, 3.44899045484375*^9, {
   3.448990497484375*^9, 3.448990579625*^9}, {3.44932366890625*^9, 
   3.4493236726875*^9}, {3.449323732109375*^9, 3.449323760515625*^9}, {
   3.44932379090625*^9, 3.449324015234375*^9}, {3.449324049109375*^9, 
   3.449324090953125*^9}, {3.449324122125*^9, 3.449324135359375*^9}, {
   3.449324167203125*^9, 3.449324284015625*^9}, {3.449324314875*^9, 
   3.44932441571875*^9}, {3.44932463953125*^9, 3.449324662015625*^9}, 
   3.4493247454375*^9, {3.449333643578125*^9, 3.44933365496875*^9}, {
   3.449343359953125*^9, 3.4467317570757437`*^9}, 3.446731799520744*^9, 
   3.4520069568012867`*^9, {3.452907345519729*^9, 3.4529073474437294`*^9}, {
   3.452907431006729*^9, 3.452907583211729*^9}, 3.458221335552*^9, {
   3.458221646226*^9, 3.458221658975*^9}, {3.4582217476619997`*^9, 
   3.458221871918*^9}, {3.458221906363*^9, 3.458221912876*^9}, {
   3.45822196526*^9, 3.458221988297*^9}, {3.45822205471*^9, 
   3.458222161767*^9}, {3.4662543236255655`*^9, 3.4662543400455656`*^9}, {
   3.4662544339135656`*^9, 3.4662545223155656`*^9}, {3.4662545527125654`*^9, 
   3.4662546942605658`*^9}, {3.4662547381415653`*^9, 
   3.4662547811015654`*^9}, {3.4662548381725655`*^9, 
   3.4662548633555655`*^9}, {3.466254902883566*^9, 3.4662549822285657`*^9}, {
   3.4662550147285657`*^9, 3.4662550559935656`*^9}, {3.4662552196915655`*^9, 
   3.4662552236095657`*^9}, {3.4662552617045655`*^9, 3.466255273864566*^9}, {
   3.4662553965115657`*^9, 3.4662554230855656`*^9}, {3.4662555675265656`*^9, 
   3.4662555695825653`*^9}, {3.4662556168485656`*^9, 
   3.4662556371515656`*^9}, {3.4662557194465656`*^9, 
   3.4662557400855656`*^9}, {3.4662558368795657`*^9, 3.466255857093566*^9}, {
   3.4766207112966595`*^9, 3.476620731861836*^9}, {3.476621070636213*^9, 
   3.47662112076108*^9}, {3.4766212184676685`*^9, 3.4766212323754635`*^9}, {
   3.476638998640636*^9, 3.476639008307189*^9}, {3.476639076480088*^9, 
   3.476639090344881*^9}, 3.4766393538739543`*^9, {3.4806978010870852`*^9, 
   3.480697805532339*^9}, {3.485451436565916*^9, 3.4854514536518936`*^9}, {
   3.4906223581670065`*^9, 3.4906223646823797`*^9}, {3.490622397158237*^9, 
   3.4906224323412495`*^9}, {3.4906224788669105`*^9, 3.490622521117327*^9}, {
   3.4906225785906143`*^9, 3.490622587032097*^9}, {3.490622685755744*^9, 
   3.490622686794803*^9}, {3.4906237682606597`*^9, 3.4906238296831727`*^9}, {
   3.490623875867814*^9, 3.490623890767667*^9}, {3.495402656509122*^9, 
   3.495402777765057*^9}, 3.495726667594631*^9, {3.4957267382196703`*^9, 
   3.4957267566607256`*^9}, {3.5010640350325537`*^9, 
   3.5010640763169155`*^9}, {3.5010641068616624`*^9, 
   3.5010641882363167`*^9}, {3.5010642988826456`*^9, 3.501064306705093*^9}, {
   3.5010643387259245`*^9, 3.501064406536803*^9}, {3.5010644936677866`*^9, 
   3.5010644976280127`*^9}, {3.5010645807887697`*^9, 
   3.5010646015179553`*^9}, {3.50106590027324*^9, 3.501065925327673*^9}, {
   3.5010660337108717`*^9, 3.5010660545150623`*^9}, {3.5010661127423925`*^9, 
   3.501066148910461*^9}, {3.5010661996283617`*^9, 3.5010662026425343`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Dimensions", "[", "dataArrayT", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "at", "]"}]}], "Input",
 CellChangeTimes->{{3.501066432977709*^9, 3.501066449219638*^9}}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{{3.501066438966051*^9, 3.501066449765669*^9}, 
   3.5010792229915857`*^9, 3.5015892846665936`*^9, 3.504099866336256*^9, 
   3.504522947425395*^9, 3.504530461073151*^9, 3.504619952449765*^9, 
   3.5165253305323677`*^9, 3.517662647281326*^9, 3.5230222273254533`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"137825", ",", "4", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{{3.501066438966051*^9, 3.501066449765669*^9}, 
   3.5010792229915857`*^9, 3.5015892846665936`*^9, 3.504099866336256*^9, 
   3.504522947425395*^9, 3.504530461073151*^9, 3.504619952449765*^9, 
   3.5165253305323677`*^9, 3.517662647281326*^9, 3.523022227356653*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesT", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i3", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArrayT", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"marketsT", "=", " ", 
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"groupsT", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}]}], "\[IndentingNewLine]", ",", 
               RowBox[{"{", 
                RowBox[{
                "i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}],
                 "}"}], ",", "Null"}], "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "at", "]"}]}], " ", "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"dataMap", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
       " ", "*)"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input"],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesT2", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i3", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArrayT2", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"marketsT2", "=", " ", 
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"groupsT2", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}]}], "\[IndentingNewLine]", ",", 
               RowBox[{"{", 
                RowBox[{
                "i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}],
                 "}"}], ",", "Null"}], "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "at2", "]"}]}], " ", "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"dataMap", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
       " ", "*)"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input",
 CellChangeTimes->{{3.5010669802610116`*^9, 3.501067040398451*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariates4", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.495726971268*^9}}],

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesTrips", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i3", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", ":=", 
        RowBox[{"at", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArrayT", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"marketsT", "=", " ", 
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"groupsT", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}],
                 "}"}], ",", "Null"}], "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "at", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"dataMap", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
       " ", "*)"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesTrips2", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"i1", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i2", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"i3", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", ":=", 
        RowBox[{"at2", "[", 
         RowBox[{"[", 
          RowBox[{"ineq", ",", "4", ",", "3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
         "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}], " ", "&&", " ", 
           RowBox[{
            RowBox[{"matchMtx", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}], 
            "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i1", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p1", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i2", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p2", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}], "+", 
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"i3", ",", 
              RowBox[{"matchMtx", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2", ",", "p3", ",", "1"}], "]"}], "]"}]}], 
             " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cov", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateObsExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"cf", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"covariateCFExpr", "[", 
                RowBox[{"DataList", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"ineq", ",", " ", "1", ",", " ", 
                 RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], ",", 
             " ", "Null"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"dataArrayT2", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"cov", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "-", 
            RowBox[{"cf", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"marketsT2", "=", " ", 
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"groupsT2", "=", 
        RowBox[{"Developer`ToPackedArray", "[", " ", 
         RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i1", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i2", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}], " ", "&&", " ", 
                RowBox[{
                 RowBox[{"matchMtx", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2", ",", "i3", ",", "1"}], "]"}], "]"}],
                  "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                "i1", ",", "i2", ",", "i3", ",", "p1", ",", "p2", ",", "p3"}],
                 "}"}], ",", "Null"}], "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"ineq", ",", " ", "1", ",", " ", 
               RowBox[{"Length", "[", "at2", "]"}]}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"dataMap", " ", "=", " ", 
        RowBox[{"Developer`ToPackedArray", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
       " ", "*)"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]}], "Input",
 CellChangeTimes->{{3.501112383283429*^9, 3.5011124462763395`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariatesGroup", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.4957269776203637`*^9}, {3.495727034851637*^9, 
  3.4957270357646894`*^9}}],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesGroup", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "i1", ",", "i2", ",", "p1", ",", "p2", ",", "cov", " ", ",", "cf"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"i1", ":=", 
       RowBox[{"apGroup", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i2", ":=", 
       RowBox[{"apGroup", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", ":=", 
       RowBox[{"apGroup", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", ":=", 
       RowBox[{"apGroup", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
        "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateObsExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "apGroup", "]"}]}], "}"}]}], "]"}], 
            ",", " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateCFExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "apGroup", "]"}]}], "}"}]}], "]"}], 
            ",", " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"dataArrayGroup", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"cov", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"cf", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"marketsG", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "apGroup", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"groupsG", "=", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "apGroup", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"individualsG", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "groupsG", "]"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataMapGroup", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"marketsG", ",", " ", "groupsG"}], "}"}], "]"}], "]"}]}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input",
 CellChangeTimes->{{3.495727052344638*^9, 3.495727055929843*^9}, 
   3.495727114090169*^9, {3.4957271594977665`*^9, 3.4957271656411176`*^9}, {
   3.4957277004727087`*^9, 3.495727709913248*^9}, {3.4957278651921296`*^9, 
   3.49572787026342*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[Cell["precomputeCovariatesGroup2", "Subsubsection",
  CellChangeTimes->{{3.495726705481798*^9, 
   3.4957267181795244`*^9}}]], "Subsubsection",
 CellChangeTimes->{{3.4957268108198233`*^9, 3.4957268118438816`*^9}, {
  3.495726949827774*^9, 3.4957269528679476`*^9}, {3.495726987203912*^9, 
  3.4957269926442227`*^9}, {3.50109232007259*^9, 3.501092321757393*^9}}],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{
   RowBox[{"precomputeCovariatesGroup2", "[", 
    RowBox[{"matchMtx_", ",", "DataList_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"i1", ":=", 
       RowBox[{"apGroup2", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i2", ":=", 
       RowBox[{"apGroup2", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", ":=", 
       RowBox[{"apGroup2", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", ":=", 
       RowBox[{"apGroup2", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateObsExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "The", " ", "above", " ", "is", " ", "the", " ", "pairwise", " ", 
        "match", " ", "from", " ", "equilibrium", " ", "pair"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateCFExpr", "[", "varM_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i1", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}], " ", "\[IndentingNewLine]", "+", 
          RowBox[{"varM", "[", 
           RowBox[{"[", 
            RowBox[{"i2", ",", 
             RowBox[{"matchMtx", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}]}], 
            " ", "]"}], "]"}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateObsExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "apGroup2", "]"}]}], "}"}]}], "]"}], 
            ",", " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"covariateCFExpr", "[", 
               RowBox[{"DataList", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ineq", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "[", "apGroup2", "]"}]}], "}"}]}], "]"}], 
            ",", " ", "Null"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"dataArrayGroup2", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"cov", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"cf", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "DataList", "]"}]}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"marketsG2", " ", "=", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", "1", "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "apGroup2", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ineq", ",", "1", ",", 
             RowBox[{"Length", "[", "ap2", "]"}]}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"groupsG2", "=", 
       RowBox[{"Developer`ToPackedArray", "[", " ", 
        RowBox[{"DeleteCases", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", " ", "[", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}], " ", "&&", " ", 
               RowBox[{
                RowBox[{"matchMtx", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}],
                 "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i1", ",", "i2"}], "}"}], ",", "Null"}], "]"}], 
            "\[IndentingNewLine]", ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "apGroup2", "]"}]}], "}"}]}], "]"}], 
          "\[IndentingNewLine]", ",", "Null"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"individualsG2", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "groupsG2", "]"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataMapGroup2", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"marketsG2", ",", " ", "groupsG2"}], "}"}], "]"}], "]"}]}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]], "Input",
 CellChangeTimes->{{3.4957268787317076`*^9, 3.4957268998369145`*^9}, {
  3.4957269325097837`*^9, 3.495726933535842*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Precomputing Data", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.4906405791525803`*^9, 3.490640583856849*^9}}],

Cell["\<\
The code below enters the data into memory\
\>", "Text",
 CellChangeTimes->{{3.5230270465097346`*^9, 3.5230270711291428`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"precomputeCovariates", "[", 
   RowBox[{"mate", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"precomputeCovariates2", "[", 
   RowBox[{"mate2", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"precomputeCovariates3", "[", 
   RowBox[{"mate3", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"precomputeCovariates4", "[", 
   RowBox[{"mate4", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4480357479375*^9, 3.44803801546875*^9, 3.44804158571875*^9, {
   3.448907241640625*^9, 3.448907243296875*^9}, {3.44898591578125*^9, 
   3.448985964578125*^9}, {3.448990423328125*^9, 3.44899044440625*^9}, {
   3.448990823125*^9, 3.4489908423125*^9}, {3.4489908976875*^9, 
   3.448990911234375*^9}, {3.449324299546875*^9, 3.44932431125*^9}, {
   3.449324430421875*^9, 3.449324500828125*^9}, {3.449324673296875*^9, 
   3.4467317657327437`*^9}, {3.4469102749367437`*^9, 3.446910284231744*^9}, {
   3.4469109597137437`*^9, 3.446910964928744*^9}, {3.446969570822744*^9, 
   3.446969579628744*^9}, {3.44735686176361*^9, 3.4473568682276096`*^9}, {
   3.452254258543287*^9, 3.452254310891287*^9}, {3.452632827852729*^9, 
   3.452632865482729*^9}, {3.452682488647729*^9, 3.4526824902477293`*^9}, {
   3.4529076238077292`*^9, 3.452907639633729*^9}, {3.452948532843729*^9, 
   3.452948538923729*^9}, {3.453087676111729*^9, 3.4530876895947294`*^9}, {
   3.4531474078207293`*^9, 3.453147436453729*^9}, {3.453147606506729*^9, 
   3.453147717829729*^9}, {3.453486198937852*^9, 3.453486229623852*^9}, {
   3.453728237430301*^9, 3.4537282400213013`*^9}, {3.454081630636301*^9, 
   3.454081640252301*^9}, 3.454081671635301*^9, {3.454170253523301*^9, 
   3.454170282124301*^9}, {3.4662550778375654`*^9, 3.4662550813735657`*^9}, {
   3.476619807764981*^9, 3.4766198116182013`*^9}, {3.4766200283555975`*^9, 
   3.4766200302577066`*^9}, {3.476620738278203*^9, 3.4766207408503504`*^9}, 
   3.4766211903880625`*^9, {3.480423511409932*^9, 3.4804235401615767`*^9}, {
   3.480526092399143*^9, 3.480526139596843*^9}, {3.4818800767512836`*^9, 
   3.481880117796632*^9}, {3.49062260387506*^9, 3.4906226087543397`*^9}, {
   3.490622729239231*^9, 3.4906227480703077`*^9}, {3.4906238404677896`*^9, 
   3.4906238492992945`*^9}, {3.4954027917608576`*^9, 
   3.4954028159392405`*^9}, {3.4954032690941596`*^9, 3.495403273712424*^9}, {
   3.4957178947808547`*^9, 3.4957178966219597`*^9}, 3.495730358379732*^9, {
   3.4958188147869716`*^9, 3.495818822422408*^9}, 3.495819259125386*^9, {
   3.4994313731339374`*^9, 3.499431375645542*^9}, {3.5010730787218237`*^9, 
   3.501073265775522*^9}, 3.5010885143991055`*^9, {3.5011661592488327`*^9, 
   3.5011662330710554`*^9}, {3.501169368732299*^9, 3.5011694159535823`*^9}, 
   3.5011694912081146`*^9, {3.5012325520168123`*^9, 3.5012325846832695`*^9}, {
   3.5165253516285744`*^9, 3.516525354332729*^9}, {3.516532737374015*^9, 
   3.516532768493795*^9}, {3.5165333828779354`*^9, 3.5165333920614605`*^9}, {
   3.5168718616489997`*^9, 3.5168718861033983`*^9}, {3.5230213784775057`*^9, 
   3.5230213884934053`*^9}, {3.52302141966746*^9, 3.5230214335046844`*^9}, {
   3.52302224168279*^9, 3.5230222463471975`*^9}, 3.5230270450206494`*^9}],

Cell[BoxData[{
 RowBox[{"precomputeCovariatesGroup", "[", 
  RowBox[{"mate", ",", 
   RowBox[{"{", 
    RowBox[{
    "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
     "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"precomputeCovariatesGroup2", "[", 
  RowBox[{"mate2", ",", 
   RowBox[{"{", 
    RowBox[{
    "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
     "notscN2", ",", "snotcN2"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4957303612228947`*^9, 3.495730402839275*^9}, {
  3.5012324382926126`*^9, 3.501232445515425*^9}, {3.5230222707037163`*^9, 
  3.523022276560395*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"precomputeCovariatesTrips", "[", 
   RowBox[{"mate", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"precomputeCovariatesTrips2", "[", 
   RowBox[{"mate2", ",", 
    RowBox[{"{", 
     RowBox[{
     "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", 
      "notscN2", ",", "snotcN2"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5010661794592085`*^9, 3.501066185744568*^9}, 
   3.5010663137078867`*^9, {3.501066910912045*^9, 3.501066958007739*^9}, {
   3.50111246908358*^9, 3.5011124734827876`*^9}, {3.501119228871853*^9, 
   3.501119234269462*^9}, {3.5168838294127245`*^9, 3.5168838335889635`*^9}, {
   3.5230222868408127`*^9, 3.523022292144822*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Dimensions", "[", "dataArray", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "dataArray2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "dataArray3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "dataArray4", "]"}]}], "Input",
 CellChangeTimes->{{3.4956336289459896`*^9, 3.4956336698193274`*^9}, {
   3.495635441403656*^9, 3.49563544530888*^9}, {3.4957279528211417`*^9, 
   3.495727953956207*^9}, 3.495730301397473*^9, 3.4957304372532434`*^9, {
   3.501067164594555*^9, 3.501067172270994*^9}, {3.501232572577648*^9, 
   3.5012325753076534`*^9}, {3.523022309866453*^9, 3.523022311832057*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "2556"}], "}"}]], "Output",
 CellChangeTimes->{3.499360938609906*^9, 3.50106717290603*^9, 
  3.5011125157744617`*^9, 3.501232575947254*^9, 3.5012326587209997`*^9, 
  3.5016010690155115`*^9, 3.5230223487960405`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "1431"}], "}"}]], "Output",
 CellChangeTimes->{3.499360938609906*^9, 3.50106717290603*^9, 
  3.5011125157744617`*^9, 3.501232575947254*^9, 3.5012326587209997`*^9, 
  3.5016010690155115`*^9, 3.5230223488060412`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "630"}], "}"}]], "Output",
 CellChangeTimes->{3.499360938609906*^9, 3.50106717290603*^9, 
  3.5011125157744617`*^9, 3.501232575947254*^9, 3.5012326587209997`*^9, 
  3.5016010690155115`*^9, 3.5230223488150415`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "903"}], "}"}]], "Output",
 CellChangeTimes->{3.499360938609906*^9, 3.50106717290603*^9, 
  3.5011125157744617`*^9, 3.501232575947254*^9, 3.5012326587209997`*^9, 
  3.5016010690155115`*^9, 3.5230223488240423`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subsampling Setup", "Subsection",
 CellChangeTimes->{{3.4906281734096193`*^9, 3.49062817918495*^9}, {
  3.4950291061036253`*^9, 3.4950291083277526`*^9}}],

Cell["The below code generates the subsampled arrays", "Text",
 CellChangeTimes->{{3.5230270261275687`*^9, 3.523027039048308*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataSubSample", "[", 
   RowBox[{"dataArrayIn_", ",", "SubSampleSize_", ",", "SS_"}], "]"}], ":=", 
  RowBox[{"Developer`ToPackedArray", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"Extract", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "dataArrayIn", "]"}], ",", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"RandomSample", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"Dimensions", "[", "dataArrayIn", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "SubSampleSize"}], 
           "]"}], ",", "1"}], "]"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "1", ",", "SS"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.50107667222436*^9, 3.501076755783139*^9}, {
  3.5010768833844376`*^9, 3.501076887725686*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataArraySS1", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArray", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySS2", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArray2", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySS3", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArray3", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySS4", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArray4", ",", "250", ",", "2000"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.501076765352687*^9, 3.5010768172256536`*^9}, {
  3.5010769085868793`*^9, 3.501076910263975*^9}, {3.516537155608723*^9, 
  3.516537162184099*^9}, {3.5230231217872534`*^9, 3.523023122203277*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataArraySS1T", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayT", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySS2T", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayT2", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5168847116986313`*^9, 3.516884720185046*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataArraySSG1", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayGroup", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySSG2", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayGroup2", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.501076765352687*^9, 3.5010768172256536`*^9}, {
  3.5010769085868793`*^9, 3.501076910263975*^9}, {3.5010928273542805`*^9, 
  3.501092835403895*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataArraySST1", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayT", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataArraySST2", "=", 
   RowBox[{"dataSubSample", "[", 
    RowBox[{"dataArrayT2", ",", "250", ",", "2000"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5011125574733353`*^9, 3.501112566755351*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x_", ",", "xValue_", ",", "N_"}], "]"}], ":=", 
   RowBox[{
    SuperscriptBox["N", 
     RowBox[{"1", "/", "3"}]], 
    RowBox[{"Abs", "[", 
     RowBox[{"x", "-", "xValue"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"T", ",", "Listable"}], "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bootstrapping Setup", "Subsection",
 CellChangeTimes->{{3.4906281734096193`*^9, 3.49062817918495*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BB", "=", "1000"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DD", ":=", 
   RowBox[{"Dimensions", "[", "dataArray", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errorMatFixed", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"DD", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"BB", ",", 
       RowBox[{"DD", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "  ", "}"}]}], " ", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4906282070095415`*^9, 3.490628207378563*^9}, {
  3.4906283620024066`*^9, 3.490628385810768*^9}, {3.4906299853782587`*^9, 
  3.4906300355391273`*^9}}],

Cell[BoxData[
 RowBox[{"errorMatFixed", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4950364945692215`*^9, 3.495036500430557*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DD2", ":=", 
   RowBox[{"Dimensions", "[", "dataArray2", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errorMatFixed2", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"DD2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"BB", ",", 
       RowBox[{"DD2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "  ", "}"}]}], " ", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{3.490630020481266*^9, 3.4954033660137033`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["R&S Subsampling Setup", "Subsection",
 CellChangeTimes->{{3.4906281734096193`*^9, 3.49062817918495*^9}, {
  3.4950291061036253`*^9, 3.4950291083277526`*^9}, {3.495911009251193*^9, 
  3.495911016451605*^9}, {3.523024741895918*^9, 3.5230247430159826`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"alpha", " ", "=", " ", 
   RowBox[{"1", "-", "0.95"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SS", "=", "2000"}], ";"}]}], "Input",
 CellChangeTimes->{{3.458220505924*^9, 3.458220563127*^9}, {3.458220701775*^9,
    3.458220702783*^9}, {3.458222374799*^9, 3.458222375295*^9}, {
   3.458223440808*^9, 3.4582234410109997`*^9}, {3.458224232534*^9, 
   3.458224232613*^9}, 3.458224408939*^9, {3.4582268348190002`*^9, 
   3.458226837296*^9}, 3.4851037629043036`*^9, {3.4851044123494496`*^9, 
   3.4851044293404217`*^9}, {3.485104477342167*^9, 3.485104479885312*^9}, {
   3.485106234990699*^9, 3.4851062413260612`*^9}, 3.4851102696774693`*^9, {
   3.4851103246216125`*^9, 3.485110365980978*^9}, {3.4851110828309793`*^9, 
   3.4851110867492037`*^9}, {3.4851125860299573`*^9, 
   3.4851126491185656`*^9}, {3.485450720772975*^9, 3.485450721991045*^9}, {
   3.4854508282301216`*^9, 3.4854508331414022`*^9}, {3.4854510220382066`*^9, 
   3.4854510252703915`*^9}, {3.4854515056058655`*^9, 3.485451515588436*^9}, {
   3.495036331899917*^9, 3.495036343178562*^9}, {3.495036596491051*^9, 
   3.4950366034534492`*^9}, {3.4950504513255024`*^9, 3.495050451932537*^9}, {
   3.495050546892968*^9, 3.495050552445286*^9}, {3.4950506072764225`*^9, 
   3.495050621646244*^9}, {3.4950507029908967`*^9, 3.495050717614733*^9}, {
   3.4950508556796303`*^9, 3.4950508644451313`*^9}, {3.4950571592461734`*^9, 
   3.4950571660635633`*^9}, {3.495131150918624*^9, 3.4951311509656267`*^9}, 
   3.4951311898938527`*^9, {3.495403397295492*^9, 3.495403406305008*^9}, {
   3.498426255555515*^9, 3.4984262600827737`*^9}, {3.499519750225279*^9, 
   3.4995197583528934`*^9}, {3.5165371308233056`*^9, 3.516537130951313*^9}, 
   3.523023654951749*^9, {3.5230247018666286`*^9, 3.523024706105871*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2000", ",", "6", ",", "250"}], "}"}]], "Output",
 CellChangeTimes->{3.5230247038377414`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">", "0"}], ",", "1", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4958973741033077`*^9, 3.49589741225849*^9}, {
   3.4958974859227033`*^9, 3.495897514386331*^9}, 3.495897597249071*^9, 
   3.4961682788491726`*^9, {3.4982237674693985`*^9, 3.498223783197298*^9}, {
   3.5230247337384515`*^9, 3.523024737098644*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">=", "0"}], ",", "1", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{3.501163788187216*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dhatFunctionSS", "[", 
   RowBox[{
   "theta_", ",", "objFunc_", ",", "Indices_", ",", "subsamples_", ",", 
    "Estimates_", ",", "alpha_"}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "Values", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Values", "=", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"objFunc", "[", 
            RowBox[{
             RowBox[{"subsamples", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "Indices", ",", 
             RowBox[{"Estimates", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "-", 
           RowBox[{"objFunc", "[", 
            RowBox[{
             RowBox[{"subsamples", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "Indices", ",", " ", 
             "theta"}], "]"}]}], " ", ")"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", 
           RowBox[{
            RowBox[{"Dimensions", "[", "subsamples", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "/", 
       "1.0000"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "subsamples", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], "]"}], "*", 
      RowBox[{"Quantile", "[", 
       RowBox[{"Values", ",", 
        RowBox[{"1", "-", "alpha"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dhatFunction", "[", 
   RowBox[{
   "theta_", ",", "objFunc_", ",", "Indices_", ",", "subsamples_", ",", 
    "objValue_", ",", "alpha_"}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "Values", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Values", "=", " ", 
      RowBox[{"objValue", "-", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"objFunc", "[", 
           RowBox[{
            RowBox[{"subsamples", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "Indices", ",", " ", 
            "theta"}], "]"}], " ", ")"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", 
           RowBox[{
            RowBox[{"Dimensions", "[", "subsamples", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Values", "=", 
      RowBox[{"Values", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Infinity", "\[Rule]", "1000"}], ",", 
         RowBox[{"Null", "->", "1000"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "subsamples", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], "]"}], "*", 
      RowBox[{"Quantile", "[", 
       RowBox[{"Values", ",", 
        RowBox[{"1", "-", "alpha"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Objectives", "Section",
 CellChangeTimes->{{3.490640662205331*^9, 3.4906406649794893`*^9}}],

Cell[CellGroupData[{

Cell["Indicator Functions", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.4906405072014647`*^9, 3.4906405113607025`*^9}, {3.4956354536093545`*^9, 
  3.495635459687702*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">", " ", "0"}], ",", "1", ",", "0"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndicatorMS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", "<", " ", "0"}], ",", "1", ",", "0"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"IndicatorS2", "[", "x_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"x", ">", "0"}], ",", "1", ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", "0"}], ",", "0.5", ",", "0"}], "]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndicatorW", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", "\[GreaterEqual]", " ", "0"}], ",", "1", ",", "0"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.4851846728030853`*^9, 3.485184673123103*^9}, {
   3.4851895859711018`*^9, 3.485189594067565*^9}, {3.4952765880041494`*^9, 
   3.4952765886091833`*^9}, {3.4994379963354387`*^9, 
   3.4994380171770754`*^9}, {3.499519351504179*^9, 3.499519362330598*^9}, 
   3.5012429357677484`*^9, {3.516525834027166*^9, 3.516525839147459*^9}, {
   3.523023157069271*^9, 3.523023158474352*^9}, {3.523023213228483*^9, 
   3.5230232167966876`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Single Variable Objectives", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.4906405232643833`*^9, 3.4906405292807274`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"objectiveS", "[", 
    RowBox[{"dataArray_", ",", "index_", ",", "sign_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{"dataArray", "[", 
        RowBox[{"[", "index", " ", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", 
         RowBox[{"sign", "*", "values"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objectiveW", "[", 
    RowBox[{"dataArray_", ",", "index_", ",", "sign_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{"dataArray", "[", 
        RowBox[{"[", "index", " ", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorW", ",", 
         RowBox[{"sign", "*", "values"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objectiveS2", "[", 
    RowBox[{"dataArray_", ",", "index_", ",", "sign_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{"dataArray", "[", 
        RowBox[{"[", "index", " ", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS2", ",", 
         RowBox[{"sign", "*", "values"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4956355815486717`*^9, 3.4956357361625156`*^9}, {
  3.4956357840502543`*^9, 3.495635817555171*^9}, {3.50487158917662*^9, 
  3.504871605210537*^9}, {3.523023231547531*^9, 3.5230232323005743`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "deptN2", ",", "deptF2", ",", " ", "coauthN2", ",", "scN2", ",", "notscN2", 
   ",", "snotcN2"}], "}"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"VariableScores", "=", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS2", "[", 
          RowBox[{"dataArray", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveW", "[", 
          RowBox[{"dataArray", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS2", "[", 
          RowBox[{"dataArray2", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveW", "[", 
          RowBox[{"dataArray2", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], "}"}], "]"}], 
    ",", 
    RowBox[{"TableHeadings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
        "\"\<Department neighbors\>\"", ",", "\"\<Department floor\>\"", ",", 
         "\"\<Coauthor neighbors\>\"", ",", 
         "\"\<Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Not-Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Friend-Not-Coauthor Neighbor\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Strong\>\"", ",", "\"\< Semi-Strong\>\"", ",", "\"\<Weak\>\"", 
         ",", "\"\<Strong\>\"", ",", "\"\< Semi-Strong\>\"", ",", 
         "\"\<Weak\>\""}], "}"}]}], " ", "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"VariableScoresNegative", "=", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS2", "[", 
          RowBox[{"dataArray", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveW", "[", 
          RowBox[{"dataArray", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS2", "[", 
          RowBox[{"dataArray2", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveW", "[", 
          RowBox[{"dataArray2", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], "}"}], "]"}], 
    ",", 
    RowBox[{"TableHeadings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
        "\"\<Department neighbors\>\"", ",", "\"\<Department floor\>\"", ",", 
         "\"\<Coauthor neighbors\>\"", ",", 
         "\"\<Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Not-Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Friend-Not-Coauthor Neighbor\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Strong\>\"", ",", "\"\< Semi-Strong\>\"", ",", "\"\<Weak\>\"", 
         ",", "\"\<Strong\>\"", ",", "\"\< Semi-Strong\>\"", ",", 
         "\"\<Weak\>\""}], "}"}]}], " ", "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5048714831935577`*^9, 3.5048715465611825`*^9}, {
  3.5048716431537075`*^9, 3.5048718099442472`*^9}, {3.5048718416870623`*^9, 
  3.5048719300301156`*^9}, {3.523023269431698*^9, 3.5230234001671753`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Strong\"\>",
       HoldForm], 
      TagBox["\<\" Semi-Strong\"\>",
       HoldForm], 
      TagBox["\<\"Weak\"\>",
       HoldForm], 
      TagBox["\<\"Strong\"\>",
       HoldForm], 
      TagBox["\<\" Semi-Strong\"\>",
       HoldForm], 
      TagBox["\<\"Weak\"\>",
       HoldForm]},
     {
      TagBox["\<\"Department neighbors\"\>",
       HoldForm], "0.5176056338028169`", "0.6926838810641628`", 
      "0.8677621283255086`", "0.5366876310272537`", "0.7131376659678547`", 
      "0.8895877009084556`"},
     {
      TagBox["\<\"Department floor\"\>",
       HoldForm], "0.5176056338028169`", "0.6926838810641628`", 
      "0.8677621283255086`", "0.5366876310272537`", "0.7131376659678547`", 
      "0.8895877009084556`"},
     {
      TagBox["\<\"Coauthor neighbors\"\>",
       HoldForm], "0.42175273865414714`", "0.672926447574335`", 
      "0.9241001564945227`", "0.5101327742837176`", "0.7225716282320056`", 
      "0.9350104821802935`"},
     {
      TagBox["\<\"Friend-Coauthor Neighbor\"\>",
       HoldForm], "0.3744131455399061`", "0.6754694835680751`", 
      "0.9765258215962441`", "0.47030048916841366`", "0.721174004192872`", 
      "0.9720475192173305`"},
     {
      TagBox["\<\"Not-Friend-Coauthor Neighbor\"\>",
       HoldForm], "0.13849765258215962`", "0.5183881064162754`", 
      "0.8982785602503912`", "0.15443745632424877`", "0.5283018867924528`", 
      "0.9021663172606569`"},
     {
      TagBox["\<\"Friend-Not-Coauthor Neighbor\"\>",
       HoldForm], "0.23200312989045385`", "0.5600547730829422`", 
      "0.8881064162754304`", "0.29559748427672955`", "0.5800139762403913`", 
      "0.8644304682040531`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "Department neighbors", "Department floor", "Coauthor neighbors", 
       "Friend-Coauthor Neighbor", "Not-Friend-Coauthor Neighbor", 
       "Friend-Not-Coauthor Neighbor"}, {
      "Strong", " Semi-Strong", "Weak", "Strong", " Semi-Strong", 
       "Weak"}}]]]], "Output",
 CellChangeTimes->{
  3.504871669226198*^9, 3.5048717317147727`*^9, {3.5048717984655905`*^9, 
   3.504871812825412*^9}, 3.504871856251896*^9, {3.504871886271613*^9, 
   3.5048718950141125`*^9}, {3.504871931283187*^9, 3.5048719555675764`*^9}, 
   3.504872004815393*^9, 3.523023370805496*^9, 3.523023401168233*^9}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Strong\"\>",
       HoldForm], 
      TagBox["\<\" Semi-Strong\"\>",
       HoldForm], 
      TagBox["\<\"Weak\"\>",
       HoldForm], 
      TagBox["\<\"Strong\"\>",
       HoldForm], 
      TagBox["\<\" Semi-Strong\"\>",
       HoldForm], 
      TagBox["\<\"Weak\"\>",
       HoldForm]},
     {
      TagBox["\<\"Department neighbors\"\>",
       HoldForm], "0.1322378716744914`", "0.30731611893583727`", 
      "0.4823943661971831`", "0.11041229909154437`", "0.28686233403214534`", 
      "0.4633123689727463`"},
     {
      TagBox["\<\"Department floor\"\>",
       HoldForm], "0.1322378716744914`", "0.30731611893583727`", 
      "0.4823943661971831`", "0.11041229909154437`", "0.28686233403214534`", 
      "0.4633123689727463`"},
     {
      TagBox["\<\"Coauthor neighbors\"\>",
       HoldForm], "0.07589984350547731`", "0.3270735524256651`", 
      "0.5782472613458529`", "0.0649895178197065`", "0.2774283717679944`", 
      "0.4898672257162823`"},
     {
      TagBox["\<\"Friend-Coauthor Neighbor\"\>",
       HoldForm], "0.023474178403755867`", "0.3245305164319249`", 
      "0.6255868544600939`", "0.02795248078266946`", "0.27882599580712786`", 
      "0.5296995108315863`"},
     {
      TagBox["\<\"Not-Friend-Coauthor Neighbor\"\>",
       HoldForm], "0.10172143974960876`", "0.4816118935837246`", 
      "0.8615023474178404`", "0.0978336827393431`", "0.4716981132075471`", 
      "0.8455625436757512`"},
     {
      TagBox["\<\"Friend-Not-Coauthor Neighbor\"\>",
       HoldForm], "0.11189358372456965`", "0.4399452269170579`", 
      "0.7679968701095462`", "0.13556953179594688`", "0.41998602375960864`", 
      "0.7044025157232704`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "Department neighbors", "Department floor", "Coauthor neighbors", 
       "Friend-Coauthor Neighbor", "Not-Friend-Coauthor Neighbor", 
       "Friend-Not-Coauthor Neighbor"}, {
      "Strong", " Semi-Strong", "Weak", "Strong", " Semi-Strong", 
       "Weak"}}]]]], "Output",
 CellChangeTimes->{
  3.504871669226198*^9, 3.5048717317147727`*^9, {3.5048717984655905`*^9, 
   3.504871812825412*^9}, 3.504871856251896*^9, {3.504871886271613*^9, 
   3.5048718950141125`*^9}, {3.504871931283187*^9, 3.5048719555675764`*^9}, 
   3.504872004815393*^9, 3.523023370805496*^9, 3.5230234013282423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", "VariableScoresNegative", "]"}]], "Input"],

Cell["\<\
\\begin{array}{ccccccc}
  & \\text{Strong} & \\text{ Semi-Strong} & \\text{Weak} & \\text{Strong} & \
\\text{ Semi-Strong} & \\text{Weak} \\\\
 \\text{Department neighbors} & 0.132238 & 0.307316 & 0.482394 & 0.110412 & \
0.286862 & 0.463312 \\\\
 \\text{Department floor} & 0.132238 & 0.307316 & 0.482394 & 0.110412 & \
0.286862 & 0.463312 \\\\
 \\text{Coauthor neighbors} & 0.0758998 & 0.327074 & 0.578247 & 0.0649895 & \
0.277428 & 0.489867 \\\\
 \\text{Friend-Coauthor Neighbor} & 0.0234742 & 0.324531 & 0.625587 & \
0.0279525 & 0.278826 & 0.5297 \\\\
 \\text{Not-Friend-Coauthor Neighbor} & 0.101721 & 0.481612 & 0.861502 & \
0.0978337 & 0.471698 & 0.845563 \\\\
 \\text{Friend-Not-Coauthor Neighbor} & 0.111894 & 0.439945 & 0.767997 & \
0.13557 & 0.419986 & 0.704403
\\end{array}\
\>", "Output",
 CellChangeTimes->{3.504872050692017*^9, 3.5230234117388377`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TeXForm", "[", "VariableScores", "]"}]], "Input",
 CellChangeTimes->{{3.5048719908925967`*^9, 3.504872047568838*^9}, {
  3.523023419418277*^9, 3.5230234197382956`*^9}}],

Cell["\<\
\\begin{array}{ccccccc}
  & \\text{Strong} & \\text{ Semi-Strong} & \\text{Weak} & \\text{Strong} & \
\\text{ Semi-Strong} & \\text{Weak} \\\\
 \\text{Department neighbors} & 0.517606 & 0.692684 & 0.867762 & 0.536688 & \
0.713138 & 0.889588 \\\\
 \\text{Department floor} & 0.517606 & 0.692684 & 0.867762 & 0.536688 & \
0.713138 & 0.889588 \\\\
 \\text{Coauthor neighbors} & 0.421753 & 0.672926 & 0.9241 & 0.510133 & \
0.722572 & 0.93501 \\\\
 \\text{Friend-Coauthor Neighbor} & 0.374413 & 0.675469 & 0.976526 & 0.4703 & \
0.721174 & 0.972048 \\\\
 \\text{Not-Friend-Coauthor Neighbor} & 0.138498 & 0.518388 & 0.898279 & \
0.154437 & 0.528302 & 0.902166 \\\\
 \\text{Friend-Not-Coauthor Neighbor} & 0.232003 & 0.560055 & 0.888106 & \
0.295597 & 0.580014 & 0.86443
\\end{array}\
\>", "Output",
 CellChangeTimes->{{3.5048719934407425`*^9, 3.504872052597126*^9}, 
   3.523023414001967*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"VariableScores", "=", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", "4"}], ",", 
           RowBox[{"objectiveS", "[", 
            RowBox[{"dataArray", ",", "i", ",", "1"}], "]"}], ",", "0"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "3", ",", "4", ",", "100", ",", "100"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", "4"}], ",", 
           RowBox[{"objectiveS", "[", 
            RowBox[{"dataArray", ",", "i", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "0"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "3", ",", "4", ",", "100", ",", "100"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
            "}"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"TableHeadings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
        "\"\<Department neighbors\>\"", ",", "\"\<Department floor\>\"", ",", 
         "\"\<Coauthor neighbors\>\"", ",", "\"\<Coauthors floor\>\"", ",", 
         "\"\<Social group neighbors\>\"", ",", "\"\<Social group floor\>\"", 
         ",", "\"\<Friend-Coauthor N\>\"", ",", "\"\<Friend-Coauthor F\>\""}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Beta]=1\>\"", ",", "\"\<\>\"", ",", "\"\<\[Beta]=-1\>\"", ",", 
         "\"\<\>\""}], "}"}]}], " ", "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "VariableScores", "]"}]}], "Input",
 CellChangeTimes->{{3.504871245909986*^9, 3.5048712469280443`*^9}, 
   3.504871341393448*^9, {3.5048713776385207`*^9, 3.5048713804386806`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"VariableScores", "=", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", "4"}], ",", 
           RowBox[{"objectiveS", "[", 
            RowBox[{"dataArray", ",", "i", ",", "1"}], "]"}], ",", "0"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "3", ",", "4", ",", "100", ",", "100"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", "4"}], ",", 
           RowBox[{"objectiveS", "[", 
            RowBox[{"dataArray", ",", "i", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "0"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{
            "1", ",", "2", ",", "3", ",", "4", ",", "100", ",", "100"}], 
            "}"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"objectiveS", "[", 
          RowBox[{"dataArray2", ",", "i", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
            "}"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"TableHeadings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
        "\"\<Department neighbors\>\"", ",", "\"\<Department floor\>\"", ",", 
         "\"\<Coauthor neighbors\>\"", ",", 
         "\"\<Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Not-Friend-Coauthor Neighbor\>\"", ",", 
         "\"\<Friend-Not-Coauthor Neighbor\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Beta]=1\>\"", ",", "\"\<\>\"", ",", "\"\<\[Beta]=-1\>\"", ",", 
         "\"\<\>\""}], "}"}]}], " ", "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "VariableScores", "]"}]}], "Input",
 CellChangeTimes->{
  3.452940844862729*^9, {3.452941033480729*^9, 3.452941040876729*^9}, {
   3.452941095961729*^9, 3.4529410964037294`*^9}, {3.453086059961729*^9, 
   3.453086075692729*^9}, {3.453147534459729*^9, 3.453147545305729*^9}, {
   3.453147744867729*^9, 3.4531479693857293`*^9}, {3.453148000246729*^9, 
   3.4531480393657293`*^9}, {3.453148103527729*^9, 3.453148125368729*^9}, {
   3.4534860979228516`*^9, 3.4534861857098517`*^9}, {3.453486238298852*^9, 
   3.453486241034852*^9}, 3.4534863464208517`*^9, {3.4534879281708517`*^9, 
   3.4534879422168517`*^9}, {3.4535023046778517`*^9, 3.453502324947852*^9}, {
   3.4956357661902328`*^9, 3.4956357724305897`*^9}, {3.49563583047991*^9, 
   3.4956359858407965`*^9}, {3.4956360222708797`*^9, 3.495636028703248*^9}, {
   3.500127447828169*^9, 3.500127513427314*^9}, {3.5001276731971517`*^9, 
   3.50012770224032*^9}, {3.500128505186743*^9, 3.5001286782251053`*^9}, {
   3.5011645614254427`*^9, 3.5011646064970207`*^9}, {3.5011662703861895`*^9, 
   3.501166290657349*^9}, {3.523023485714069*^9, 3.5230234903043313`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"\[Beta]=1\"\>",
       HoldForm], 
      TagBox["\<\"\"\>",
       HoldForm], 
      TagBox["\<\"\[Beta]=-1\"\>",
       HoldForm], 
      TagBox["\<\"\"\>",
       HoldForm]},
     {
      TagBox["\<\"Department neighbors\"\>",
       HoldForm], "0.5176056338028169`", "0.5366876310272537`", 
      "0.1322378716744914`", "0.11041229909154437`"},
     {
      TagBox["\<\"Department floor\"\>",
       HoldForm], "0.5176056338028169`", "0.5366876310272537`", 
      "0.1322378716744914`", "0.11041229909154437`"},
     {
      TagBox["\<\"Coauthor neighbors\"\>",
       HoldForm], "0.42175273865414714`", "0.5101327742837176`", 
      "0.07589984350547731`", "0.0649895178197065`"},
     {
      TagBox["\<\"Friend-Coauthor Neighbor\"\>",
       HoldForm], "0.3744131455399061`", "0.47030048916841366`", 
      "0.023474178403755867`", "0.02795248078266946`"},
     {
      TagBox["\<\"Not-Friend-Coauthor Neighbor\"\>",
       HoldForm], "0", "0.15443745632424877`", "0", "0.0978336827393431`"},
     {
      TagBox["\<\"Friend-Not-Coauthor Neighbor\"\>",
       HoldForm], "0", "0.29559748427672955`", "0", "0.13556953179594688`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "Department neighbors", "Department floor", "Coauthor neighbors", 
       "Friend-Coauthor Neighbor", "Not-Friend-Coauthor Neighbor", 
       "Friend-Not-Coauthor Neighbor"}, {
      "\[Beta]=1", "", "\[Beta]=-1", ""}}]]]], "Output",
 CellChangeTimes->{
  3.4956359893439965`*^9, 3.495636034569583*^9, 3.495639513398561*^9, 
   3.4956664301631117`*^9, 3.4982237166644926`*^9, 3.498417585291604*^9, 
   3.4993477371437397`*^9, 3.499361155983186*^9, 3.499431413709609*^9, 
   3.499432475854288*^9, 3.499519479330803*^9, 3.5001262063909807`*^9, 
   3.500127159155355*^9, 3.500127515883648*^9, 3.5001277039108124`*^9, 
   3.500128123692119*^9, 3.5001285937807364`*^9, 3.5001286243713903`*^9, 
   3.500128681416478*^9, 3.5003059614233923`*^9, 3.500764794878045*^9, {
   3.501164584055737*^9, 3.50116460893616*^9}, {3.501166293236497*^9, 
   3.5011663106814947`*^9}, 3.5011664534496603`*^9, 3.523023491209383*^9}],

Cell["\<\
\\begin{array}{ccccc}
  & \\text{$\\beta $=1} & \\text{} & \\text{$\\beta $=-1} & \\text{} \\\\
 \\text{Department neighbors} & 0.517606 & 0.536688 & 0.132238 & 0.110412 \\\\
 \\text{Department floor} & 0.517606 & 0.536688 & 0.132238 & 0.110412 \\\\
 \\text{Coauthor neighbors} & 0.421753 & 0.510133 & 0.0758998 & 0.0649895 \\\\
 \\text{Friend-Coauthor Neighbor} & 0.374413 & 0.4703 & 0.0234742 & 0.0279525 \
\\\\
 \\text{Not-Friend-Coauthor Neighbor} & 0 & 0.154437 & 0 & 0.0978337 \\\\
 \\text{Friend-Not-Coauthor Neighbor} & 0 & 0.295597 & 0 & 0.13557
\\end{array}\
\>", "Output",
 CellChangeTimes->{
  3.4956359893439965`*^9, 3.495636034569583*^9, 3.495639513398561*^9, 
   3.4956664301631117`*^9, 3.4982237166644926`*^9, 3.498417585291604*^9, 
   3.4993477371437397`*^9, 3.499361155983186*^9, 3.499431413709609*^9, 
   3.499432475854288*^9, 3.499519479330803*^9, 3.5001262063909807`*^9, 
   3.500127159155355*^9, 3.500127515883648*^9, 3.5001277039108124`*^9, 
   3.500128123692119*^9, 3.5001285937807364`*^9, 3.5001286243713903`*^9, 
   3.500128681416478*^9, 3.5003059614233923`*^9, 3.500764794878045*^9, {
   3.501164584055737*^9, 3.50116460893616*^9}, {3.501166293236497*^9, 
   3.5011663106814947`*^9}, 3.5011664534496603`*^9, 3.5230234912413845`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.4906406491275826`*^9, 3.49064065659301*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation Objectives", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.4906404667691526`*^9, 3.490640468944277*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"objective2min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "onesorzero", "]"}], "/", "1."}], "-", 
        RowBox[{"0.000001", "*", 
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"Boole", "[", 
          RowBox[{
           RowBox[{"beta", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective2max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "onesorzero", "]"}], "/", "1."}], "+", 
        RowBox[{"0.000001", "*", 
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"Boole", "[", 
          RowBox[{
           RowBox[{"beta", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "<", "100"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective2", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective3", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective3min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "minVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "onesorzero", "]"}], "/", "1."}], "-", 
        RowBox[{"0.000001", "*", "minVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"minVar", ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective3max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "maxVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "onesorzero", "]"}], "/", "1."}], "+", 
        RowBox[{"0.000001", "*", "maxVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"maxVar", "<", "100"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective4min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "minVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "-", 
        RowBox[{"0.00001", "*", "minVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"minVar", ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective4", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective4max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "maxVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "+", 
        RowBox[{"0.000001", "*", "maxVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"maxVar", "<", "10000"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective5", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective5max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "maxVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "+", 
        RowBox[{"0.000001", "*", "maxVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"maxVar", "<", "10000"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective5min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "minVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "-", 
        RowBox[{"0.00001", "*", "minVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"minVar", ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective6", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective6max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "maxVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "+", 
        RowBox[{"0.000001", "*", "maxVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"maxVar", "<", "10000"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective6min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "minVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "-", 
        RowBox[{"0.00001", "*", "minVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"minVar", ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective7", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "7", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "1.0"}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective7max", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "maxVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "7", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "+", 
        RowBox[{"0.000001", "*", "maxVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"maxVar", "<", "100"}], "]"}]}]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"objective7min", "[", 
    RowBox[{"dataArray_", ",", "indices_", ",", "beta_", ",", "minVar_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", "score", ",", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", 
          RowBox[{"indices", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "5", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "6", "]"}], "]"}], " ", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", 
           RowBox[{"indices", "[", 
            RowBox[{"[", "7", "]"}], "]"}], " ", "]"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"IndicatorS", ",", "values"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"score", "=", 
       RowBox[{
        RowBox[{"Total", "[", "onesorzero", "]"}], "-", 
        RowBox[{"0.00001", "*", "minVar", "*", 
         RowBox[{"Boole", "[", 
          RowBox[{"minVar", ">", 
           RowBox[{"-", "100"}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.452680294215729*^9, 3.452680307669729*^9}, {
   3.452681136230729*^9, 3.452681141893729*^9}, {3.452681344762729*^9, 
   3.452681388059729*^9}, {3.452682516746729*^9, 3.4526825400767293`*^9}, {
   3.452682663810729*^9, 3.4526826713467293`*^9}, 3.4526829936137295`*^9, {
   3.452683443059729*^9, 3.4526834431397295`*^9}, {3.452683836909729*^9, 
   3.452683881595729*^9}, {3.452683936696729*^9, 3.452683944012729*^9}, {
   3.4526839879127293`*^9, 3.4526839880247293`*^9}, {3.452694799600729*^9, 
   3.452694838081729*^9}, {3.452695668809729*^9, 3.452695688250729*^9}, {
   3.4526962616727295`*^9, 3.4526962653117294`*^9}, {3.452696791591729*^9, 
   3.452696797110729*^9}, {3.452697129927729*^9, 3.452697178887729*^9}, {
   3.453217037092729*^9, 3.453217114900729*^9}, {3.453217391689729*^9, 
   3.4532174513307295`*^9}, {3.453217524578729*^9, 3.453217543567729*^9}, {
   3.4532180353047295`*^9, 3.4532180718897295`*^9}, {3.453218584711729*^9, 
   3.453218593808729*^9}, {3.4537299357483015`*^9, 3.4537299958873014`*^9}, {
   3.453730381701301*^9, 3.4537303821193013`*^9}, {3.4537305902583013`*^9, 
   3.453730674187301*^9}, {3.453730908959301*^9, 3.4537309582243013`*^9}, {
   3.4537310377833014`*^9, 3.453731068786301*^9}, {3.4537314116983013`*^9, 
   3.4537314478563013`*^9}, {3.453731864648301*^9, 3.4537318737223015`*^9}, {
   3.4537319693873014`*^9, 3.4537319725543013`*^9}, {3.453732022767301*^9, 
   3.453732026017301*^9}, {3.4537320665143013`*^9, 3.453732106851301*^9}, {
   3.453854829713301*^9, 3.453854844716301*^9}, 3.453891580242301*^9, {
   3.4538924122903013`*^9, 3.4538924130673013`*^9}, {3.453892688895301*^9, 
   3.453892689588301*^9}, {3.458052064803*^9, 3.4580521066070004`*^9}, {
   3.4580522105559998`*^9, 3.458052211226*^9}, 3.458052267381*^9, {
   3.458052582366*^9, 3.4580526364230003`*^9}, {3.458208142533*^9, 
   3.458208234774*^9}, {3.47663667742387*^9, 3.4766366801930285`*^9}, {
   3.480423610839619*^9, 3.480423620152152*^9}, {3.480423655856194*^9, 
   3.480423797700307*^9}, {3.480423903665368*^9, 3.480423916416097*^9}, {
   3.4804239766915445`*^9, 3.480423978482647*^9}, {3.480424035087885*^9, 
   3.4804240423002977`*^9}, {3.4805263089665303`*^9, 3.480526317072994*^9}, {
   3.4805264381599197`*^9, 3.4805264407220664`*^9}, {3.4805266100307503`*^9, 
   3.480526631415973*^9}, {3.4805266788426857`*^9, 3.4805266790456977`*^9}, 
   3.4805293198977456`*^9, {3.4805297859584026`*^9, 3.4805297976610723`*^9}, {
   3.4806871406393423`*^9, 3.480687199286697*^9}, {3.480687490633361*^9, 
   3.4806875525079*^9}, {3.4806991560145826`*^9, 3.480699167409234*^9}, {
   3.480699421296756*^9, 3.4806994262730403`*^9}, {3.480699912600857*^9, 
   3.4806999145189667`*^9}, {3.480701680655984*^9, 3.4807017790546117`*^9}, {
   3.4807018448433747`*^9, 3.4807018717079115`*^9}, {3.480702456949385*^9, 
   3.480702472142254*^9}, {3.4807036260442533`*^9, 3.480703626123258*^9}, {
   3.4807036885818305`*^9, 3.480703697615347*^9}, {3.4807044039377465`*^9, 
   3.4807044240358963`*^9}, {3.4807072646923723`*^9, 3.480707286092596*^9}, {
   3.480711511487275*^9, 3.4807115205097914`*^9}, {3.4815466760112247`*^9, 
   3.4815466969394217`*^9}, {3.4815504997359295`*^9, 
   3.4815505176279526`*^9}, {3.4815888076140146`*^9, 3.481588832934463*^9}, {
   3.481588873232768*^9, 3.481588891772828*^9}, {3.481638268540018*^9, 
   3.4816383164687595`*^9}, {3.4818805884615517`*^9, 3.481880639324461*^9}, {
   3.481880837515797*^9, 3.4818808661414347`*^9}, 3.4819819995289335`*^9, 
   3.4850961590803895`*^9, {3.4850961963515215`*^9, 3.4850962072441444`*^9}, {
   3.4850963007284913`*^9, 3.485096334761438*^9}, {3.485107053119493*^9, 
   3.4851070531774964`*^9}, {3.485180313351739*^9, 3.4851804041199303`*^9}, {
   3.485444292468297*^9, 3.485444324654138*^9}, {3.490100105634087*^9, 
   3.490100126939306*^9}, {3.4906228463219275`*^9, 3.490622915476883*^9}, {
   3.4906230297784204`*^9, 3.4906230751090136`*^9}, {3.4906231330893297`*^9, 
   3.4906231518564034`*^9}, {3.490623488548661*^9, 3.4906235283719387`*^9}, {
   3.490624876560051*^9, 3.490624920705576*^9}, {3.4906251912930527`*^9, 
   3.4906252033427415`*^9}, {3.490625307493699*^9, 3.49062537727569*^9}, {
   3.490628562023847*^9, 3.490628576600681*^9}, {3.4951266843461504`*^9, 
   3.495126735307065*^9}, {3.4951288232194867`*^9, 3.4951288702411766`*^9}, {
   3.495134407242875*^9, 3.4951344153323374`*^9}, {3.4951360831517315`*^9, 
   3.495136100719736*^9}, {3.495137281746287*^9, 3.495137302096451*^9}, {
   3.495225095163927*^9, 3.495225148483977*^9}, 3.4952251917744527`*^9, 
   3.495226961704687*^9, {3.4952781187767043`*^9, 3.4952781276002088`*^9}, {
   3.4953030459004545`*^9, 3.495303060234274*^9}, 3.495308532889292*^9, {
   3.499438029376297*^9, 3.499438054648341*^9}, {3.499519492934027*^9, 
   3.499519494930831*^9}, {3.5006445904146028`*^9, 3.5006446211483607`*^9}, {
   3.5006447762452316`*^9, 3.5006448948980184`*^9}, {3.500645087656043*^9, 
   3.500645088586097*^9}, {3.501617472918439*^9, 3.5016175307009406`*^9}, {
   3.5016175784214244`*^9, 3.501617620759899*^9}, {3.5041162462371325`*^9, 
   3.504116275280794*^9}, {3.504530658055418*^9, 3.5045307051551123`*^9}, {
   3.504532552483773*^9, 3.5045326499393473`*^9}, {3.504533423604598*^9, 
   3.504533423892615*^9}, {3.5230235148007326`*^9, 3.5230235301206083`*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pairwise Assessments (Indicator functions)", "Subtitle",
 CellChangeTimes->{{3.490625625059862*^9, 3.4906256362905045`*^9}, {
  3.4906257358872013`*^9, 3.490625745391745*^9}}],

Cell[CellGroupData[{

Cell["Objective PS 1", "Section",
 CellChangeTimes->{{3.452679218515729*^9, 3.4526792224487295`*^9}, {
   3.452683894453729*^9, 3.4526838945667295`*^9}, {3.4526885366207294`*^9, 
   3.452688536749729*^9}, 3.4526948570757294`*^9, {3.452940550499729*^9, 
   3.4529405574157295`*^9}, 3.4532171351727295`*^9, {3.4906256161943555`*^9, 
   3.490625616401367*^9}}],

Cell[CellGroupData[{

Cell["Estimation", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"OutputResultsPS1min", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective2min", "[", 
     RowBox[{"dataArray", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
    RowBox[{"{", "b2", "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mseEstimatePS1min", "=", 
   RowBox[{"b2", "/.", 
    RowBox[{
     RowBox[{"OutputResultsPS1min", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"OutputResultsPS1max", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective2max", "[", 
     RowBox[{"dataArray", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
    RowBox[{"{", "b2", "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mseEstimatePS1max", "=", 
   RowBox[{"b2", "/.", 
    RowBox[{
     RowBox[{"OutputResultsPS1max", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4580523444449997`*^9, 3.45805237994*^9}, 
   3.4580526585*^9, {3.4662598563675656`*^9, 3.4662598580635653`*^9}, {
   3.476620385156006*^9, 3.47662038627907*^9}, {3.4805311790980864`*^9, 
   3.4805311792500944`*^9}, {3.4806992831858563`*^9, 
   3.4806993229461308`*^9}, {3.480699728962353*^9, 3.480699783600478*^9}, {
   3.4806998684813333`*^9, 3.480699881025051*^9}, {3.485096167807889*^9, 
   3.4850961682559147`*^9}, {3.4906229551241508`*^9, 
   3.4906229833167634`*^9}, {3.4906231925647316`*^9, 3.49062319585992*^9}, {
   3.4906257568534007`*^9, 3.490625758789511*^9}, {3.495897191830882*^9, 
   3.4958972085338373`*^9}, {3.495897677942686*^9, 3.4958977799095182`*^9}, {
   3.4958978182987137`*^9, 3.495897879576219*^9}, {3.49589806597688*^9, 
   3.495898101094889*^9}, {3.4984175615092435`*^9, 3.4984175639253817`*^9}, {
   3.498427379445798*^9, 3.498427389877394*^9}, 3.498427625413866*^9, {
   3.5165329198664527`*^9, 3.5165329235466633`*^9}, {3.5168024357513866`*^9, 
   3.516802441133396*^9}, {3.5168036778411684`*^9, 3.5168036808519735`*^9}, {
   3.516803724859651*^9, 3.516803728166857*^9}, {3.5168706439093485`*^9, 
   3.5168706452534256`*^9}, {3.5168711627090225`*^9, 
   3.5168711645011253`*^9}, {3.516884119804737*^9, 3.5168841570264025`*^9}, {
   3.5168843129179697`*^9, 3.516884315494117*^9}, {3.5230237189414086`*^9, 
   3.5230237241577067`*^9}, {3.5230238024941874`*^9, 
   3.5230238185421057`*^9}, {3.5230238843658705`*^9, 
   3.5230238851179132`*^9}, {3.523024060909968*^9, 3.5230240637101283`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1392.0000000714274`", ",", 
   RowBox[{"{", 
    RowBox[{"b2", "\[Rule]", 
     RowBox[{"-", "0.07142734995683032`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.458052398553*^9, 3.4662598103365655`*^9, 3.466259885614566*^9, 
   3.4805271969433193`*^9, 3.4805312020623994`*^9, 3.48069927712451*^9, 
   3.4806993368969283`*^9, {3.480699748407466*^9, 3.4806997700567036`*^9}, 
   3.4807005663862514`*^9, 3.4815472956376657`*^9, 3.481564700858187*^9, 
   3.4815706030207715`*^9, 3.481889244207632*^9, 3.48225677442514*^9, 
   3.4906229747852755`*^9, 3.490623082671446*^9, {3.490623170067445*^9, 
   3.4906231990461025`*^9}, 3.490625796368661*^9, 3.4906285888843837`*^9, 
   3.495028324482919*^9, 3.4950525621322336`*^9, 3.4951264972634497`*^9, 
   3.4951364798384204`*^9, 3.495234758516639*^9, {3.495897183937431*^9, 
   3.4958972098949156`*^9}, {3.495897695406685*^9, 3.495897743839455*^9}, 
   3.4958978268692045`*^9, {3.4958978601651087`*^9, 3.495897883403438*^9}, {
   3.4958980903452744`*^9, 3.4958981035640306`*^9}, 3.4982237599699697`*^9, 
   3.4982237977871323`*^9, 3.4984175667895455`*^9, 3.4984176052067432`*^9, {
   3.498427598288315*^9, 3.498427628268029*^9}, 3.499347824427695*^9, 
   3.4994380661143613`*^9, 3.499519526801687*^9, 3.5002973089244556`*^9, 
   3.500306161238821*^9, 3.501083340494018*^9, 3.5011007602178144`*^9, 
   3.516802448013008*^9, 3.516803641040704*^9, 3.516803683145178*^9, 
   3.5168037304288607`*^9, 3.5168706482405963`*^9, {3.516884125763948*^9, 
   3.5168841616339197`*^9}, 3.5168843187913055`*^9, 3.523023728705967*^9, {
   3.523023805700371*^9, 3.523023825154484*^9}, 3.523023890412216*^9, 
   3.5230241084656878`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1392.0000000833331`", ",", 
   RowBox[{"{", 
    RowBox[{"b2", "\[Rule]", "0.08333317027121316`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.458052398553*^9, 3.4662598103365655`*^9, 3.466259885614566*^9, 
   3.4805271969433193`*^9, 3.4805312020623994`*^9, 3.48069927712451*^9, 
   3.4806993368969283`*^9, {3.480699748407466*^9, 3.4806997700567036`*^9}, 
   3.4807005663862514`*^9, 3.4815472956376657`*^9, 3.481564700858187*^9, 
   3.4815706030207715`*^9, 3.481889244207632*^9, 3.48225677442514*^9, 
   3.4906229747852755`*^9, 3.490623082671446*^9, {3.490623170067445*^9, 
   3.4906231990461025`*^9}, 3.490625796368661*^9, 3.4906285888843837`*^9, 
   3.495028324482919*^9, 3.4950525621322336`*^9, 3.4951264972634497`*^9, 
   3.4951364798384204`*^9, 3.495234758516639*^9, {3.495897183937431*^9, 
   3.4958972098949156`*^9}, {3.495897695406685*^9, 3.495897743839455*^9}, 
   3.4958978268692045`*^9, {3.4958978601651087`*^9, 3.495897883403438*^9}, {
   3.4958980903452744`*^9, 3.4958981035640306`*^9}, 3.4982237599699697`*^9, 
   3.4982237977871323`*^9, 3.4984175667895455`*^9, 3.4984176052067432`*^9, {
   3.498427598288315*^9, 3.498427628268029*^9}, 3.499347824427695*^9, 
   3.4994380661143613`*^9, 3.499519526801687*^9, 3.5002973089244556`*^9, 
   3.500306161238821*^9, 3.501083340494018*^9, 3.5011007602178144`*^9, 
   3.516802448013008*^9, 3.516803641040704*^9, 3.516803683145178*^9, 
   3.5168037304288607`*^9, 3.5168706482405963`*^9, {3.516884125763948*^9, 
   3.5168841616339197`*^9}, 3.5168843187913055`*^9, 3.523023728705967*^9, {
   3.523023805700371*^9, 3.523023825154484*^9}, 3.523023890412216*^9, 
   3.5230241140670085`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">", "0"}], ",", "1", ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", "0"}], ",", "0.5", ",", "0"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"objective2", "[", 
  RowBox[{"dataArray", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", "mseEstimatePS1min", "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">=", "0"}], ",", "1", ",", "0"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"objective2", "[", 
  RowBox[{"dataArray", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", "mseEstimatePS1min", "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.516803610807851*^9, 3.5168036364230957`*^9}, {
  3.5168037347344685`*^9, 3.516803749351694*^9}, {3.5168842516854672`*^9, 
  3.516884260259958*^9}, {3.523025480989192*^9, 3.523025507020681*^9}}],

Cell[BoxData["0.6926838810641628`"], "Output",
 CellChangeTimes->{3.516803650868721*^9, 3.5168037501004953`*^9, 
  3.5168842662733016`*^9, 3.5230237569465823`*^9, 3.523024275330232*^9, 
  3.523025482722291*^9, 3.523025513330042*^9}],

Cell[BoxData["0.8407668231611893`"], "Output",
 CellChangeTimes->{3.516803650868721*^9, 3.5168037501004953`*^9, 
  3.5168842662733016`*^9, 3.5230237569465823`*^9, 3.523024275330232*^9, 
  3.523025482722291*^9, 3.523025513340042*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subsampling", "Subsection",
 CellChangeTimes->{{3.490628118434475*^9, 3.490628121072626*^9}, {
   3.4950362951928177`*^9, 3.495036297367942*^9}, 3.4959114498743954`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BB", "=", "2000"}], ";"}]], "Input",
 CellChangeTimes->{{3.5165448429774156`*^9, 3.5165448445835075`*^9}, 
   3.523024300314661*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetSharedVariable", "[", "outputPS1", " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", 
   RowBox[{
   "objective2", ",", "objective2min", ",", "objective2max", ",", 
    "dataArraySS1", ",", "dataArraySS2", ",", "dataArraySS3", ",", 
    "IndicatorS", ",", "k", ",", "BB"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputPS1", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Null", ",", "Null"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parallelize", "[", "\[IndentingNewLine]", 
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"outputPS1", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective2min", "[", 
          RowBox[{
           RowBox[{"dataArraySS1", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], ",", 
           RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
         RowBox[{"{", "b2", "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS1", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective2max", "[", 
          RowBox[{
           RowBox[{"dataArraySS1", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], ",", 
           RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
         RowBox[{"{", "b2", "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mod", "[", 
          RowBox[{"b", ",", " ", "250"}], "]"}], " ", "==", " ", "0"}], ",", 
        " ", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Iterations completed: \>\"", "<>", 
          RowBox[{"ToString", "[", "b", "]"}]}], "]"}]}], "]"}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b2", "/.", 
        RowBox[{"outputPS1", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "/.", 
        RowBox[{"outputPS1", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "2", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.498417832058718*^9, 3.498417909856168*^9}, 
   3.4984179485353804`*^9, {3.4984182283273835`*^9, 3.498418228999422*^9}, {
   3.498418307348903*^9, 3.498418335015486*^9}, {3.498418374455742*^9, 
   3.498418387639496*^9}, 3.498418426262705*^9, 3.498427398457885*^9, {
   3.4993478622937336`*^9, 3.499347933849739*^9}, {3.4993481796901035`*^9, 
   3.4993482069058666`*^9}, {3.4993485890344267`*^9, 3.4993486679329395`*^9}, 
   3.499349185762557*^9, {3.499351391507459*^9, 3.499351420785942*^9}, {
   3.499351485567954*^9, 3.4993514937612543`*^9}, {3.49955588321299*^9, 
   3.499555917907451*^9}, {3.501083381818491*^9, 3.5010834165597515`*^9}, {
   3.5010836600761795`*^9, 3.5010836611993814`*^9}, {3.5165372064296303`*^9, 
   3.516537220975462*^9}, {3.516544863247575*^9, 3.5165448644806457`*^9}, {
   3.516546564561885*^9, 3.5165465657289515`*^9}, {3.5165468193274565`*^9, 
   3.516546820545526*^9}, {3.516870039206464*^9, 3.516870045540075*^9}, {
   3.5168706823295465`*^9, 3.516870684073646*^9}, {3.5168711397377086`*^9, 
   3.516871139849715*^9}, {3.5168713855137663`*^9, 3.5168713864088173`*^9}, {
   3.5168715944257154`*^9, 3.5168715953217664`*^9}, {3.5230243056669674`*^9, 
   3.523024336225715*^9}}],

Cell[BoxData[{
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"EstimatesPS1", "[", 
      RowBox[{"[", 
       RowBox[{"b", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"EstimatesPS1", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "1"}], "]"}], "]"}], "<", 
        RowBox[{"-", "1000"}]}], ",", 
       RowBox[{"-", "1000"}], ",", 
       RowBox[{"EstimatesPS1", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"EstimatesPS1", "[", 
      RowBox[{"[", 
       RowBox[{"b", ",", "2"}], "]"}], "]"}], "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"EstimatesPS1", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "1"}], "]"}], "]"}], ">", "1000"}], ",", "1000", 
       ",", 
       RowBox[{"EstimatesPS1", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS1min", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS1", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS1max", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS1", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.499351495793939*^9, 3.499351604402773*^9}, {
  3.500116318814348*^9, 3.5001163199832125`*^9}}],

Cell[BoxData[{
 RowBox[{"CritValPS1min", "=", 
  RowBox[{"Quantile", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", "EstimatesPS1min", "]"}], ",", 
      "mseEstimatePS1min", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", "dataArraySS1", "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"CritValPS1max", "=", 
  RowBox[{"Quantile", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", "EstimatesPS1max", "]"}], ",", 
      "mseEstimatePS1max", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", "dataArraySS1", "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.5000573670299573`*^9, 3.500057434542819*^9}, {
  3.500057602352417*^9, 3.500057644047802*^9}, {3.5002973541481495`*^9, 
  3.5002973633976784`*^9}, {3.500297401509858*^9, 3.50029740310995*^9}, {
  3.501083722273489*^9, 3.5010837313683043`*^9}, {3.5011087111617794`*^9, 
  3.5011087141257844`*^9}, {3.5165462690489826`*^9, 3.5165462944734364`*^9}, {
  3.516546609882477*^9, 3.5165466109695387`*^9}, {3.516546834986352*^9, 
  3.516546836281426*^9}, {3.5168703060200224`*^9, 3.5168703091712027`*^9}, {
  3.5168710450112906`*^9, 3.516871046387369*^9}, {3.516871147732166*^9, 
  3.516871149251253*^9}, {3.5168714120202823`*^9, 3.5168714134113617`*^9}, {
  3.5168716108676558`*^9, 3.5168716117957087`*^9}}],

Cell[BoxData[{
 RowBox[{"CritValsPS1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", 
     RowBox[{"x", "/.", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "mseEstimatePS1min", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", "CritValPS1min"}], 
        ",", "x"}], "]"}]}], "]"}], ",", 
    RowBox[{"Max", "[", 
     RowBox[{"x", "/.", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "mseEstimatePS1max", ",", 
           RowBox[{
            RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", "CritValPS1max"}], 
        ",", "x"}], "]"}]}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"ciPS1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "CritValsPS1", "]"}], ",", 
    RowBox[{"Max", "[", "CritValsPS1", "]"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.500057828362344*^9, 3.500057966864266*^9}, {
  3.5000580044804173`*^9, 3.500058083632945*^9}, {3.500297382356763*^9, 
  3.500297393606406*^9}, {3.5002974317335873`*^9, 3.500297443573264*^9}, {
  3.501083790882409*^9, 3.5010837915532103`*^9}, {3.5011005167169867`*^9, 
  3.5011005309754114`*^9}, {3.5165466159638247`*^9, 3.5165466176459208`*^9}, {
  3.5165468409546933`*^9, 3.516546843498839*^9}, {3.5168703452852683`*^9, 
  3.5168703485164533`*^9}, {3.5168710417961063`*^9, 3.516871043892226*^9}, {
  3.5168711519564075`*^9, 3.51687115515559*^9}, {3.5168714157164936`*^9, 
  3.5168714186606617`*^9}, {3.5168716154949207`*^9, 3.516871617462033*^9}, {
  3.5230245814367404`*^9, 3.5230245822047844`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Romano and Shaikh", "Subsection",
 CellChangeTimes->{{3.501283855489564*^9, 3.5012838604698486`*^9}}],

Cell[BoxData[
 RowBox[{"QvalPS1", "=", 
  RowBox[{"objective2", "[", 
   RowBox[{"dataArray", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", "mseEstimatePS1max", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.50128397413935*^9, 3.501284027062377*^9}, {
  3.5012840637824774`*^9, 3.501284069094781*^9}, {3.523024819483356*^9, 
  3.5230248260267305`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dPS1", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"dhatFunction", "[", 
   RowBox[{"\[Theta]", ",", "objective2", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", "dataArraySS1", ",", "QvalPS1", ",",
     "0.05"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5012838931937203`*^9, 3.5012839646498075`*^9}, {
  3.5012840453384223`*^9, 3.501284100678588*^9}}],

Cell[BoxData[
 RowBox[{"dPS1", "[", 
  RowBox[{"{", "0.1", "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.52302483861345*^9, 3.523024855066391*^9}}],

Cell[BoxData[
 RowBox[{"(", 
  RowBox[{"QvalPS1", "-", 
   RowBox[{"objective2", "[", 
    RowBox[{"dataArray", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", "0.1", "}"}]}], "]"}]}], ")"}]], "Input",
 CellChangeTimes->{{3.523024898730889*^9, 3.5230249003149796`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AcceptancePS1", "[", 
   RowBox[{"\[Theta]_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"QvalPS1", "-", 
        RowBox[{"objective2", "[", 
         RowBox[{"dataArray", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", "\[Theta]", "}"}]}], "]"}]}], ")"}]}], "\[LessEqual]", 
     " ", 
     RowBox[{"dPS1", "[", 
      RowBox[{"{", "\[Theta]", "}"}], "]"}]}], ",", "a", ",", "b"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5012842276348495`*^9, 3.501284405864043*^9}, {
  3.5012844852235823`*^9, 3.50128449461712*^9}}],

Cell[BoxData[
 RowBox[{"AcceptancePS1", "[", 
  RowBox[{"0.1", ",", "1", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.5230249204741325`*^9, 3.52302492812257*^9}, {
  3.5230249647786665`*^9, 3.523024966122743*^9}}],

Cell["\<\
Ignore the errors here, failure to convert into numerical form.\
\>", "Text",
 CellChangeTimes->{{3.523025211780794*^9, 3.5230252346641026`*^9}}],

Cell[BoxData[{
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS1", "[", 
    RowBox[{"\[Theta]", ",", "\[Theta]", ",", 
     RowBox[{"-", "100"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0.08"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS1", "[", 
    RowBox[{"\[Theta]", ",", "\[Theta]", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0.08"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5012843767853804`*^9, 3.5012845278310194`*^9}, {
  3.501284683480922*^9, 3.50128469690469*^9}, {3.5230250861706095`*^9, 
  3.523025102347535*^9}, {3.523025199195074*^9, 3.523025206075468*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Objective PS 2", "Section",
 CellChangeTimes->{{3.452679218515729*^9, 3.4526792224487295`*^9}, {
   3.452683894453729*^9, 3.4526838945667295`*^9}, {3.4526885366207294`*^9, 
   3.452688536749729*^9}, 3.4526948570757294`*^9, {3.452940550499729*^9, 
   3.4529405574157295`*^9}, 3.4532171351727295`*^9}],

Cell[CellGroupData[{

Cell["Estimation", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, 
   3.52302449610386*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"outputResultsPS2min", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective2min", "[", 
     RowBox[{"dataArray", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
    RowBox[{"{", "b2", "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mseEstimatePS2min", "=", 
   RowBox[{"b2", "/.", 
    RowBox[{
     RowBox[{"outputResultsPS2min", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS2max", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective2max", "[", 
     RowBox[{"dataArray", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
    RowBox[{"{", "b2", "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mseEstimatePS2max", "=", 
   RowBox[{"b2", "/.", 
    RowBox[{
     RowBox[{"outputResultsPS2max", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.458052123152*^9, 3.4580521332019997`*^9}, 
   3.458052275352*^9, {3.458052389521*^9, 3.458052401267*^9}, 
   3.458052474045*^9, {3.4662599178675656`*^9, 3.4662599187475653`*^9}, {
   3.4766204029010205`*^9, 3.476620405365162*^9}, {3.480531260365734*^9, 
   3.480531260851762*^9}, {3.480700651089096*^9, 3.4807006777136188`*^9}, {
   3.4816386107705927`*^9, 3.4816386149548316`*^9}, {3.485096187358007*^9, 
   3.4850961880470467`*^9}, {3.4850962195508485`*^9, 3.48509624177512*^9}, {
   3.485096343902961*^9, 3.485096397933051*^9}, {3.485096442302589*^9, 
   3.485096519985032*^9}, {3.485096607616044*^9, 3.485096618591672*^9}, {
   3.485096747009017*^9, 3.485096750657226*^9}, {3.4850968037122602`*^9, 
   3.4850968250064783`*^9}, {3.485106577775305*^9, 3.4851066122222753`*^9}, {
   3.485110455759113*^9, 3.485110456318145*^9}, {3.485447648840271*^9, 
   3.485447648918275*^9}, {3.490623334529852*^9, 3.490623410450194*^9}, {
   3.490625761411661*^9, 3.4906257632687674`*^9}, {3.490626312148162*^9, 
   3.49062631229217*^9}, {3.495051554572604*^9, 3.4950515912477016`*^9}, {
   3.495052210335112*^9, 3.4950522141753316`*^9}, {3.49616135376408*^9, 
   3.4961613967915416`*^9}, {3.4982257790064516`*^9, 3.4982257860008516`*^9}, 
   3.498225956050578*^9, 3.498230521678717*^9, {3.4984285054001985`*^9, 
   3.4984285081513557`*^9}, 3.501163919694738*^9, {3.516802493939489*^9, 
   3.5168024969346943`*^9}, {3.51680296123831*^9, 3.5168029636407137`*^9}, {
   3.516803122526993*^9, 3.516803147424637*^9}, {3.51680334878979*^9, 
   3.5168033526897974`*^9}, {3.516803458442383*^9, 3.516803461172388*^9}, {
   3.5168671278630953`*^9, 3.516867131700702*^9}, {3.5168901065689526`*^9, 
   3.5168901132243333`*^9}, {3.523024503310272*^9, 3.523024504222324*^9}, 
   3.5230252498679724`*^9, {3.523025404573821*^9, 3.523025405613881*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1671.9999959999952`", ",", 
   RowBox[{"{", 
    RowBox[{"b2", "\[Rule]", "4.000004814585354`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4851028584495716`*^9, 3.4851065962533617`*^9, 3.485106626572096*^9, 
   3.485106677781025*^9, {3.4851104272004795`*^9, 3.4851104580452433`*^9}, 
   3.4854476509953938`*^9, 3.48544883035485*^9, {3.490623387457879*^9, 
   3.4906234132553544`*^9}, 3.4906257994958396`*^9, {3.4950515746827545`*^9, 
   3.4950515933678236`*^9}, 3.4950522153874006`*^9, 3.4951359417196417`*^9, 
   3.4952355882080946`*^9, 3.49616125637351*^9, 3.496161398745653*^9, 
   3.4961617265524025`*^9, 3.4961633216816387`*^9, 3.49822590555169*^9, 
   3.498225958231703*^9, 3.498420362699463*^9, 3.4984286958130894`*^9, 
   3.499355739896398*^9, 3.4994361703522315`*^9, 3.4994380758331785`*^9, 
   3.499520444691699*^9, 3.5003097702002416`*^9, 3.5010838450925045`*^9, 
   3.501100864800398*^9, 3.5011009046584682`*^9, 3.504523111558783*^9, 
   3.5047058391672044`*^9, 3.5168025003979006`*^9, 3.516802969147524*^9, {
   3.516803126848201*^9, 3.5168031502326417`*^9}, 3.5168033652790194`*^9, 
   3.516803471546406*^9, 3.516868088933984*^9, 3.516890116968547*^9, 
   3.523025245754737*^9, 3.52302536818674*^9, 3.5230254111851997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1672.000004999999`", ",", 
   RowBox[{"{", 
    RowBox[{"b2", "\[Rule]", "4.999998958296272`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4851028584495716`*^9, 3.4851065962533617`*^9, 3.485106626572096*^9, 
   3.485106677781025*^9, {3.4851104272004795`*^9, 3.4851104580452433`*^9}, 
   3.4854476509953938`*^9, 3.48544883035485*^9, {3.490623387457879*^9, 
   3.4906234132553544`*^9}, 3.4906257994958396`*^9, {3.4950515746827545`*^9, 
   3.4950515933678236`*^9}, 3.4950522153874006`*^9, 3.4951359417196417`*^9, 
   3.4952355882080946`*^9, 3.49616125637351*^9, 3.496161398745653*^9, 
   3.4961617265524025`*^9, 3.4961633216816387`*^9, 3.49822590555169*^9, 
   3.498225958231703*^9, 3.498420362699463*^9, 3.4984286958130894`*^9, 
   3.499355739896398*^9, 3.4994361703522315`*^9, 3.4994380758331785`*^9, 
   3.499520444691699*^9, 3.5003097702002416`*^9, 3.5010838450925045`*^9, 
   3.501100864800398*^9, 3.5011009046584682`*^9, 3.504523111558783*^9, 
   3.5047058391672044`*^9, 3.5168025003979006`*^9, 3.516802969147524*^9, {
   3.516803126848201*^9, 3.5168031502326417`*^9}, 3.5168033652790194`*^9, 
   3.516803471546406*^9, 3.516868088933984*^9, 3.516890116968547*^9, 
   3.523025245754737*^9, 3.52302536818674*^9, 3.523025415941471*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">", "0"}], ",", "1", ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", "0"}], ",", "0.5", ",", "0"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"objective2", "[", 
  RowBox[{"dataArray", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", "mseEstimatePS2min", "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">=", "0"}], ",", "1", ",", "0"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"objective2", "[", 
  RowBox[{"dataArray", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", "mseEstimatePS2min", "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.501100417157612*^9, 3.5011004380928483`*^9}, {
   3.516533116730713*^9, 3.5165331603672085`*^9}, {3.516533191705001*^9, 
   3.5165332138962708`*^9}, {3.51653325847182*^9, 3.51653325864883*^9}, {
   3.516803252880822*^9, 3.5168032573112297`*^9}, {3.516803374701436*^9, 
   3.516803417975912*^9}, {3.516803464713594*^9, 3.5168034671159983`*^9}, {
   3.5230252601725616`*^9, 3.523025264843829*^9}, 3.523025371227914*^9, {
   3.523025524332671*^9, 3.5230255261087723`*^9}}],

Cell[BoxData["0.7517605633802817`"], "Output",
 CellChangeTimes->{{3.501100428077631*^9, 3.5011004396060514`*^9}, 
   3.5011015856464643`*^9, {3.501163784095982*^9, 3.5011637917554197`*^9}, {
   3.516533147825491*^9, 3.516533214618312*^9}, {3.5165332595168796`*^9, 
   3.516533272972649*^9}, 3.51680326303644*^9, 3.5168033165289335`*^9, 
   3.516803375855838*^9, 3.5168034359471436`*^9, 3.5168034810936227`*^9, {
   3.5230252529831505`*^9, 3.5230252669379487`*^9}, 3.523025369860836*^9, 
   3.5230254204327283`*^9, 3.5230255269628215`*^9}],

Cell[BoxData["0.8493740219092332`"], "Output",
 CellChangeTimes->{{3.501100428077631*^9, 3.5011004396060514`*^9}, 
   3.5011015856464643`*^9, {3.501163784095982*^9, 3.5011637917554197`*^9}, {
   3.516533147825491*^9, 3.516533214618312*^9}, {3.5165332595168796`*^9, 
   3.516533272972649*^9}, 3.51680326303644*^9, 3.5168033165289335`*^9, 
   3.516803375855838*^9, 3.5168034359471436`*^9, 3.5168034810936227`*^9, {
   3.5230252529831505`*^9, 3.5230252669379487`*^9}, 3.523025369860836*^9, 
   3.5230254204327283`*^9, 3.523025526971822*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subsampling", "Subsection",
 CellChangeTimes->{{3.490628118434475*^9, 3.490628121072626*^9}, {
  3.4950362951928177`*^9, 3.495036297367942*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetSharedVariable", "[", "outputPS2", " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", 
   RowBox[{
   "objective2", ",", "objective2min", ",", "objective2max", ",", 
    "dataArraySS1", ",", "BB", ",", "IndicatorS", ",", "k"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputPS2", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Null", ",", "Null"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parallelize", "[", "\[IndentingNewLine]", 
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"outputPS2", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective2min", "[", 
          RowBox[{
           RowBox[{"dataArraySS1", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3"}], "}"}], ",", 
           RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
         RowBox[{"{", "b2", "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
            RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "200"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS2", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective2max", "[", 
          RowBox[{
           RowBox[{"dataArraySS1", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3"}], "}"}], ",", 
           RowBox[{"{", "b2", "}"}]}], "]"}], ",", 
         RowBox[{"{", "b2", "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
            RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "200"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mod", "[", 
          RowBox[{"b", ",", " ", "250"}], "]"}], " ", "==", " ", "0"}], ",", 
        " ", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Iterations completed: \>\"", "<>", 
          RowBox[{"ToString", "[", "b", "]"}]}], "]"}]}], "]"}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4984204113042426`*^9, 3.498420430873362*^9}, {
   3.498420585864227*^9, 3.4984205861042404`*^9}, {3.498428501322965*^9, 
   3.4984285031640706`*^9}, {3.4993532232880344`*^9, 3.499353405137373*^9}, {
   3.4995464305479875`*^9, 3.499546456896434*^9}, {3.501083879100564*^9, 
   3.501083900987403*^9}, {3.5168671465519285`*^9, 3.516867148408332*^9}, {
   3.5168900901420126`*^9, 3.5168900975684376`*^9}, {3.523025550100145*^9, 
   3.523025575119576*^9}, 3.5230256922102733`*^9}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"EstimatesPS2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<EstimatesPS2-250.csv\>\"", ",", "\"\<csv\>\""}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EstimatesPS2min", "=", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Transpose", "[", "EstimatesPS2", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EstimatesPS2max", "=", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Transpose", "[", "EstimatesPS2", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.501101042063509*^9, 3.501101060268741*^9}, {
  3.5011011418412848`*^9, 3.50110115613091*^9}, {3.501101341568435*^9, 
  3.501101343565239*^9}}],

Cell[BoxData[
 RowBox[{"CritValPS2min", "=", 
  RowBox[{"Quantile", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", "EstimatesPS2min", "]"}], ",", 
      "mseEstimatePS2min", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", "dataArraySS1", "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.95"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.5168902090448136`*^9, 3.5230255845551157`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CritValPS2min", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS2min", "]"}], ",", 
       "mseEstimatePS2min", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS1", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS2max", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS2max", "]"}], ",", 
       "mseEstimatePS2max", ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS1", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValsPS2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mseEstimatePS2min", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", "CritValPS2min"}],
          ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mseEstimatePS2max", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", "CritValPS2max"}],
          ",", "x"}], "]"}]}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ciPS2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "CritValsPS2", "]"}], ",", 
    RowBox[{"Max", "[", "CritValsPS2", "]"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.5000573670299573`*^9, 3.500057434542819*^9}, {
  3.500057602352417*^9, 3.500057644047802*^9}, {3.500058261120096*^9, 
  3.5000582698085933`*^9}, {3.50005844615968*^9, 3.5000585202433724`*^9}, {
  3.5010864578786936`*^9, 3.5010865080171814`*^9}, {3.5010880732459307`*^9, 
  3.5010880744159327`*^9}, {3.501088289649511*^9, 3.5010883048127375`*^9}, {
  3.501088428505355*^9, 3.501088461125012*^9}, {3.501108686466936*^9, 
  3.5011086895713415`*^9}, {3.516890218105332*^9, 3.516890223130619*^9}, {
  3.52302558550317*^9, 3.523025590655464*^9}}],

Cell[BoxData[
 RowBox[{"Quantile", "[", 
  RowBox[{"EstimatesPS2max", ",", "0.975"}], "]"}]], "Input",
 CellChangeTimes->{{3.5168699127994413`*^9, 3.5168699351386805`*^9}}],

Cell[BoxData["CritValsPS2"], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Romano and Shaikh", "Subsection",
 CellChangeTimes->{{3.501283855489564*^9, 3.5012838604698486`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QvalPS2", "=", 
  RowBox[{"objective2", "[", 
   RowBox[{"dataArray", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", "mseEstimatePS2max", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.50128397413935*^9, 3.501284027062377*^9}, {
  3.5012840637824774`*^9, 3.501284069094781*^9}, {3.501284873543793*^9, 
  3.5012848764859614`*^9}, {3.501284940391617*^9, 3.501284942742751*^9}, {
  3.523025624171382*^9, 3.5230256286666384`*^9}}],

Cell[BoxData["0.7517605633802817`"], "Output",
 CellChangeTimes->{3.501284033199728*^9, 3.5012840703018503`*^9, 
  3.501284878877098*^9, 3.501284911930989*^9, 3.5012849446028576`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dPS2", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"dhatFunction", "[", 
   RowBox[{"\[Theta]", ",", "objective2", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], ",", "dataArraySS1", ",", "QvalPS2", ",",
     "0.05"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5012838931937203`*^9, 3.5012839646498075`*^9}, {
  3.5012840453384223`*^9, 3.501284100678588*^9}, {3.5012849513832455`*^9, 
  3.5012849567745533`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AcceptancePS2", "[", 
   RowBox[{"\[Theta]_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArray", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"QvalPS2", "-", 
        RowBox[{"objective2", "[", 
         RowBox[{"dataArray", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}], ",", 
          RowBox[{"{", "\[Theta]", "}"}]}], "]"}]}], ")"}]}], "\[LessEqual]", 
     " ", 
     RowBox[{"dPS2", "[", 
      RowBox[{"{", "\[Theta]", "}"}], "]"}]}], ",", "a", ",", "b"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5012842276348495`*^9, 3.501284405864043*^9}, {
  3.5012844852235823`*^9, 3.50128449461712*^9}, {3.5012849773857327`*^9, 
  3.5012849912075233`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS2", "[", 
    RowBox[{"\[Theta]", ",", "\[Theta]", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "4.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5012843767853804`*^9, 3.5012845278310194`*^9}, {
  3.501284683480922*^9, 3.50128469690469*^9}, {3.501284997030856*^9, 
  3.501285023719383*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9.219504892854502`*^-8", ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", "\[Rule]", "9.219504892854502`*^-8"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.501284400576741*^9, 3.5012844450332837`*^9}, 
   3.501284639791423*^9, 3.5012850735582333`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AcceptancePS2", "[", 
      RowBox[{"\[Theta]", ",", "\[Theta]", ",", 
       RowBox[{"-", "100"}]}], "]"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", " ", "100"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "4.99"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.501284999271984*^9, 3.501285014806873*^9}, {
  3.5012851821884465`*^9, 3.5012851917839956`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"99.9999990499`", ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", "\[Rule]", "99.9999990499`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5012848118642654`*^9, 3.5012851488325386`*^9, 
  3.5012852251099014`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Objective PS 3", "Section",
 CellChangeTimes->{{3.4580524682349997`*^9, 3.45805248841*^9}, {
   3.4906234603370476`*^9, 3.490623462111149*^9}, 3.490624265729113*^9, {
   3.4906249674892516`*^9, 3.49062496763326*^9}, 3.5230257487625074`*^9}],

Cell[CellGroupData[{

Cell["Estimation with Extended Survey", "Subsection",
 CellChangeTimes->{{3.490640327470185*^9, 3.4906403290592756`*^9}, {
  3.4954045915618005`*^9, 3.4954045952900133`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"outputResultsPS3min2", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4min", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b2"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min2", "=", 
  RowBox[{"b2", "/.", 
   RowBox[{"outputResultsPS3min2", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min2a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3min2", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS3max2", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4max", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b2"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max2", "=", 
  RowBox[{"b2", "/.", 
   RowBox[{"outputResultsPS3max2", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max2a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3max2", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS3min3", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4min", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b3"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min3", "=", 
  RowBox[{"b3", "/.", 
   RowBox[{"outputResultsPS3min3", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min3a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3min3", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS3max3", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4max", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b3"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max3", "=", 
  RowBox[{"b3", "/.", 
   RowBox[{"outputResultsPS3max3", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max3a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3max3", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS3min4", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4min", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b4"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min4", "=", 
  RowBox[{"b4", "/.", 
   RowBox[{"outputResultsPS4min4", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3min4a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3min4", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"outputResultsPS3max4", "=", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"objective4max", "[", 
     RowBox[{"dataArray2", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b4"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<DifferentialEvolution\>\"", ",", 
       RowBox[{"\"\<SearchPoints\>\"", "\[Rule]", "600"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max4", "=", 
  RowBox[{"b4", "/.", 
   RowBox[{"outputResultsPS3max4", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"mse3max4a", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], "/.", 
   RowBox[{"outputResultsPS3max4", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAGIQ/eO8x9+rjK8cX9zfCqZPGDsLXAPS0wxniIDo441L
zUG0hvtaaxAd9WquB4j2lbsIpo9sD9kJooVvee4C0WsWMRwG0c1cnKdB9Pp/
+ndBtHbkVTA9h6NRp5frlSPz1pN6IFrPz3XVbCDNk/RuLYgWenhyL4i+ufbS
VRCtdrN4wlwgvaKmZxKIXnTUrXIJkG4rW98OosV4OieCaH3Wrvkg+mXYrp6j
QLru5KM+EL0v0WU6iFbgrpoNohsqS+5cEn3lmPra/gGI7rwdtszL+JWjGfuc
5SD6Xo/8GhC9aLXVWhAttU/r+BEgvXoW9wUQnXPxxIY3QJrt0PpNIPpX953s
xfavHJk8UwtAdM0poXIQ/argMJi2uZJeA6LF41bXgmju4MxZIFqoVXoBiAYA
XD3A/g==
  "]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1245.9999698993124`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "3.01006874993735`"}], ",", 
     RowBox[{"b3", "\[Rule]", "0.005028848474003204`"}], ",", 
     RowBox[{"b4", "\[Rule]", "6.8237309137408015`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230261948340216`*^9}],

Cell[BoxData["3.01006874993735`"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026194842022*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.01006874993735`", ",", "0.005028848474003204`", ",", 
   "6.8237309137408015`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230261948490224`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1246.000004476655`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "4.476655017186425`"}], ",", 
     RowBox[{"b3", "\[Rule]", "0.4867188580860084`"}], ",", 
     RowBox[{"b4", "\[Rule]", "9.23908204496087`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262080317764`*^9}],

Cell[BoxData["4.476655017186425`"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026208038777*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4.476655017186425`", ",", "0.4867188580860084`", ",", 
   "9.23908204496087`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262080467772`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1245.9999999999027`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "3.488499234175846`"}], ",", 
     RowBox[{"b3", "\[Rule]", "9.736805605160289`*^-6"}], ",", 
     RowBox[{"b4", "\[Rule]", "7.17833629839534`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026219612439*^9}],

Cell[BoxData["9.736805605160289`*^-6"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026219619439*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.488499234175846`", ",", "9.736805605160289`*^-6", ",", 
   "7.17833629839534`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262196274395`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1246.0000004999788`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "4.030954931652996`"}], ",", 
     RowBox[{"b3", "\[Rule]", "0.4999787213569265`"}], ",", 
     RowBox[{"b4", "\[Rule]", "8.85256881586812`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026233009205*^9}],

Cell[BoxData["0.4999787213569265`"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262330152054`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4.030954931652996`", ",", "0.4999787213569265`", ",", 
   "8.85256881586812`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026233022206*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1245.9999390651535`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "3.0467274825233672`"}], ",", 
     RowBox[{"b3", "\[Rule]", "0.015508518138295815`"}], ",", 
     RowBox[{"b4", "\[Rule]", "6.093484653809011`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026246401971*^9}],

Cell[BoxData["6.093484653809011`"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262464099717`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0467274825233672`", ",", "0.015508518138295815`", ",", 
   "6.093484653809011`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026246416972*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1246.000009412201`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", "4.4818861048010366`"}], ",", 
     RowBox[{"b3", "\[Rule]", "0.48978013793347214`"}], ",", 
     RowBox[{"b4", "\[Rule]", "9.412200972686804`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.523026260675788*^9}],

Cell[BoxData["9.412200972686804`"], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262606837883`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4.4818861048010366`", ",", "0.48978013793347214`", ",", 
   "9.412200972686804`"}], "}"}]], "Output",
 CellChangeTimes->{{3.490623641551412*^9, 3.4906236619255776`*^9}, {
   3.490623941199551*^9, 3.490623967836075*^9}, 3.4906240724600587`*^9, {
   3.4906250596645236`*^9, 3.490625079913682*^9}, 3.4906251144036546`*^9, 
   3.4906252106491594`*^9, 3.4906252640092115`*^9, 3.490625385037134*^9, 
   3.4906258114745245`*^9, 3.4906260211295166`*^9, 3.4952249831075177`*^9, 
   3.4952265350482836`*^9, 3.495240585801941*^9, 3.4952409733651085`*^9, 
   3.495308551334347*^9, 3.4954042483961725`*^9, 3.495408159264861*^9, 
   3.498498468969886*^9, 3.4999952196921115`*^9, 3.5011028572514973`*^9, 
   3.501108299742257*^9, 3.50452512665504*^9, 3.5047058532760115`*^9, 
   3.5165273549121556`*^9, 3.5165274203999014`*^9, 3.51655252023653*^9, 
   3.5165525617539043`*^9, 3.516802650750964*^9, 3.5168027009986525`*^9, 
   3.5168039010931606`*^9, 3.5168844212105207`*^9, 3.5230258628560333`*^9, 
   3.5230259149110107`*^9, 3.5230262606897883`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", "1", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"x", "\[Equal]", "0"}], ",", "0.5", ",", "0"}], "]"}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"objective4", "[", 
    RowBox[{"dataArray2", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", "mse4max3a"}], 
    "]"}], "\n", 
   RowBox[{
    RowBox[{"IndicatorS", "[", "x_", "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", ">=", "0"}], ",", "1", ",", "0"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"objective4", "[", 
    RowBox[{"dataArray2", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", "mse4max3a"}], 
    "]"}], "\n"}]}]], "Input",
 CellChangeTimes->{
  3.504635449889168*^9, {3.516527194058955*^9, 3.516527243302772*^9}, {
   3.516527291991557*^9, 3.5165272920705614`*^9}, {3.5165273894791327`*^9, 
   3.5165273944394164`*^9}, {3.516803836758648*^9, 3.5168038811563253`*^9}, 
   3.5168039283308086`*^9, {3.523026121740841*^9, 3.523026123356933*^9}, {
   3.523026188764674*^9, 3.523026214717159*^9}}],

Cell[BoxData["0.8218029350104822`"], "Output",
 CellChangeTimes->{{3.5165272443538322`*^9, 3.516527250890206*^9}, {
   3.516527292603592*^9, 3.5165273083484926`*^9}, {3.516527395340468*^9, 
   3.5165274037589493`*^9}, {3.5165274538688154`*^9, 3.5165274655814857`*^9}, 
   3.516803930468012*^9, 3.5230261286212344`*^9, 3.523026260876799*^9, 
   3.5230264994744463`*^9}],

Cell[BoxData["0.8707197763801537`"], "Output",
 CellChangeTimes->{{3.5165272443538322`*^9, 3.516527250890206*^9}, {
   3.516527292603592*^9, 3.5165273083484926`*^9}, {3.516527395340468*^9, 
   3.5165274037589493`*^9}, {3.5165274538688154`*^9, 3.5165274655814857`*^9}, 
   3.516803930468012*^9, 3.5230261286212344`*^9, 3.523026260876799*^9, 
   3.5230264994814463`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subsampling", "Subsection",
 CellChangeTimes->{{3.490628118434475*^9, 3.490628121072626*^9}, {
   3.4950362951928177`*^9, 3.495036297367942*^9}, 3.498498514901513*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetSharedVariable", "[", "outputPS3", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", 
   RowBox[{
   "objective4min", ",", "objective4max", ",", "k", ",", "dataArraySS2", ",", 
    "BB", ",", "IndicatorS"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputPS3", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", ",", 
       "Null"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parallelize", "[", "\[IndentingNewLine]", 
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4min", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b2"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4max", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b2"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "3"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4min", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b3"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "4"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4max", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b3"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "5"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4min", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b4"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outputPS3", "[", 
        RowBox[{"[", 
         RowBox[{"b", ",", "6"}], "]"}], "]"}], "=", 
       RowBox[{"NMaximize", "[", 
        RowBox[{
         RowBox[{"objective4max", "[", 
          RowBox[{
           RowBox[{"dataArraySS2", "[", 
            RowBox[{"[", "b", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", "b4"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"b2", ",", "b3", ",", "b4"}], "}"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", "\"\<DifferentialEvolution\>\"", "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mod", "[", 
          RowBox[{"b", ",", " ", "250"}], "]"}], " ", "==", " ", "0"}], ",", 
        " ", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Iterations completed: \>\"", "<>", 
          RowBox[{"ToString", "[", "b", "]"}]}], "]"}]}], "]"}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b2", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "2", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b3", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "3", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b3", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "4", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b4", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "5", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"b4", "/.", 
        RowBox[{"outputPS3", "[", 
         RowBox[{"[", 
          RowBox[{"b", ",", "6", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "BB"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3min1", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3max1", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3min2", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3max2", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3min3", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EstimatesPS3max3", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "EstimatesPS3", "]"}], "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4999952407989483`*^9, 3.4999954885585833`*^9}, {
   3.4999957311546097`*^9, 3.4999957434942317`*^9}, {3.500063337823115*^9, 
   3.5000633526691184`*^9}, {3.5001127460629525`*^9, 
   3.5001127549642334`*^9}, {3.5011029686200933`*^9, 3.5011030644198613`*^9}, 
   3.5011030986151214`*^9, 3.5011031418583975`*^9, {3.516552577043779*^9, 
   3.516552587714389*^9}, {3.5168654402365313`*^9, 3.5168654693773823`*^9}, {
   3.516884799261585*^9, 3.516884814019211*^9}, {3.5230265131072254`*^9, 
   3.523026528675116*^9}, {3.523026620640376*^9, 3.5230266543543043`*^9}, {
   3.52302668905929*^9, 3.523026721503145*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CritValPS3min1", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3min1", "]"}], ",", "mse3min2", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS3max1", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3max1", "]"}], ",", "mse3max2", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS3min2", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3min2", "]"}], ",", "mse3min3", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS3max2", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3max2", "]"}], ",", "mse3max3", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS3min3", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3min3", "]"}], ",", "mse3min4", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValPS3max3", "=", 
   RowBox[{"Quantile", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "EstimatesPS3max3", "]"}], ",", "mse3max4", 
       ",", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArraySS2", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ",", "0.975"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValsPS3d1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3min2", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", 
          "CritValPS3min1"}], ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3max2", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}], "==", 
          "CritValPS3max1"}], ",", "x"}], "]"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValsPS3d2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3min3", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", 
          "CritValPS3min2"}], ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3max3", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}], "==", 
          "CritValPS3max2"}], ",", "x"}], "]"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CritValsPS3d3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3min4", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", 
          "CritValPS3min3"}], ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"x", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "mse3max4", ",", 
            RowBox[{
             RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}], "==", 
          "CritValPS3max3"}], ",", "x"}], "]"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ciPS3d1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "CritValsPS3d1", "]"}], ",", 
    RowBox[{"Max", "[", "CritValsPS3d1", "]"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"ciPS3d2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "CritValsPS3d2", "]"}], ",", 
    RowBox[{"Max", "[", "CritValsPS3d2", "]"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"ciPS3d3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "CritValsPS3d3", "]"}], ",", 
    RowBox[{"Max", "[", "CritValsPS3d3", "]"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.5000319862266884`*^9, 3.50003199842591*^9}, {
  3.500112707929486*^9, 3.5001127271757298`*^9}, {3.5001127612837715`*^9, 
  3.5001127801483917`*^9}, {3.500113071465149*^9, 3.5001132037035074`*^9}, {
  3.5001132579680424`*^9, 3.500113329779127*^9}, {3.500113715732587*^9, 
  3.500113719486991*^9}, {3.5001139506848927`*^9, 3.500113953916668*^9}, {
  3.5011081788732443`*^9, 3.501108240524553*^9}, {3.5011084214068704`*^9, 
  3.5011084468037148`*^9}, {3.5165526041863317`*^9, 3.5165526240274663`*^9}, {
  3.516865535537099*^9, 3.5168655558639345`*^9}, {3.516884827154434*^9, 
  3.516884842660861*^9}, {3.5230265452890663`*^9, 3.5230266168241577`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.33965820706574396`"}], ",", "0.7700753041455833`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.500113337876164*^9, 3.500113733807763*^9, 3.501108244284159*^9, {
   3.501108440017703*^9, 3.501108447833317*^9}, 3.501112217439538*^9, {
   3.516554787175191*^9, 3.5165548026500764`*^9}, 3.5168680873115807`*^9, 
   3.516889949022941*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13.898150718412724`", ",", "11697.949578648719`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.500113337876164*^9, 3.500113733807763*^9, 3.501108244284159*^9, {
   3.501108440017703*^9, 3.501108447833317*^9}, 3.501112217439538*^9, {
   3.516554787175191*^9, 3.5165548026500764`*^9}, 3.5168680873115807`*^9, 
   3.5168899490579433`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Romano and Shaikh", "Subsection",
 CellChangeTimes->{{3.501283855489564*^9, 3.5012838604698486`*^9}}],

Cell[BoxData[
 RowBox[{"QvalPS3", "=", 
  RowBox[{"objective4", "[", 
   RowBox[{"dataArray2", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", "mse4max4a"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.50128397413935*^9, 3.501284027062377*^9}, {
  3.5012840637824774`*^9, 3.501284069094781*^9}, {3.501284873543793*^9, 
  3.5012848764859614`*^9}, {3.501284940391617*^9, 3.501284942742751*^9}, {
  3.5012852802960577`*^9, 3.5012852845022984`*^9}, {3.5230267466985865`*^9, 
  3.5230267562981358`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dPS3", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"dhatFunction", "[", 
   RowBox[{"\[Theta]", ",", "objective4", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", "dataArraySS2", 
    ",", "QvalPS3", ",", "0.1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5012838931937203`*^9, 3.5012839646498075`*^9}, {
   3.5012840453384223`*^9, 3.501284100678588*^9}, {3.5012849513832455`*^9, 
   3.5012849567745533`*^9}, {3.5012852888725486`*^9, 3.501285312518901*^9}, 
   3.5012945434038773`*^9, {3.523026732810792*^9, 3.523026748218673*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AcceptancePS3", "[", 
   RowBox[{"\[Theta]_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "dataArray2", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"QvalPS3", "-", 
        RowBox[{"objective4", "[", 
         RowBox[{"dataArray2", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "5", ",", "6", ",", "4"}], "}"}], ",", 
          "\[Theta]"}], "]"}]}], ")"}]}], "\[LessEqual]", " ", 
     RowBox[{"dPS3", "[", "\[Theta]", "]"}]}], ",", "a", ",", "b"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5012842276348495`*^9, 3.501284405864043*^9}, {
  3.5012844852235823`*^9, 3.50128449461712*^9}, {3.5012849773857327`*^9, 
  3.5012849912075233`*^9}, {3.501285319096277*^9, 3.501285344056705*^9}, {
  3.501285459322298*^9, 3.5012854774483347`*^9}, {3.5012855469373093`*^9, 
  3.5012855490814314`*^9}, {3.5230267398681955`*^9, 3.5230267416272964`*^9}, {
  3.523026778636413*^9, 3.5230267860598373`*^9}}],

Cell[BoxData[{
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS3", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",", 
     "\[Theta]1", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "3.0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.03"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "7.02"}], "}"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS3", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",", 
     "\[Theta]2", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "3.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.03"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "7.02"}], "}"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"AcceptancePS3", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",", 
     "\[Theta]3", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "3.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.03"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "7.02"}], "}"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5012843767853804`*^9, 3.5012845278310194`*^9}, {
  3.501284683480922*^9, 3.50128469690469*^9}, {3.501284997030856*^9, 
  3.501285023719383*^9}, {3.501285396119683*^9, 3.5012854506147995`*^9}, {
  3.501285494488309*^9, 3.50128552912829*^9}, {3.5230267941873026`*^9, 
  3.5230268074370604`*^9}, {3.5230268485554123`*^9, 3.523026851997609*^9}}],

Cell[BoxData[{
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AcceptancePS3", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",",
        "\[Theta]1", ",", 
       RowBox[{"-", "100"}]}], "]"}], ",", 
     RowBox[{"\[Theta]1", "<=", "100"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "4.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "8.96"}], "}"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AcceptancePS3", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",",
        "\[Theta]2", ",", 
       RowBox[{"-", "100"}]}], "]"}], ",", 
     RowBox[{"\[Theta]2", "<=", "100"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "4.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "8.96"}], "}"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AcceptancePS3", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]3"}], "}"}], ",",
        "\[Theta]3", ",", 
       RowBox[{"-", "100"}]}], "]"}], ",", 
     RowBox[{"\[Theta]3", "<=", "100"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]1", ",", "4.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]2", ",", "0.47"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]3", ",", "8.96"}], "}"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5012843767853804`*^9, 3.5012845278310194`*^9}, {
  3.501284683480922*^9, 3.50128469690469*^9}, {3.501284997030856*^9, 
  3.501285023719383*^9}, {3.501285396119683*^9, 3.5012854506147995`*^9}, {
  3.501285494488309*^9, 3.50128552912829*^9}, {3.5012856375604925`*^9, 
  3.5012856661841297`*^9}, {3.5012857062664223`*^9, 3.5012857225033507`*^9}, {
  3.523026868075529*^9, 3.5230268770070395`*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1632, 972},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 276, 6, 47, "Text"],
Cell[CellGroupData[{
Cell[846, 30, 98, 1, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[969, 35, 149, 2, 71, "Section"],
Cell[1121, 39, 241, 4, 31, "Input"],
Cell[1365, 45, 298, 5, 31, "Input"],
Cell[1666, 52, 1259, 31, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2962, 88, 100, 1, 41, "Section"],
Cell[CellGroupData[{
Cell[3087, 93, 208, 3, 36, "Subsection"],
Cell[3298, 98, 2299, 50, 92, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5634, 153, 160, 3, 36, "Subsection"],
Cell[5797, 158, 4937, 95, 312, "Input"],
Cell[CellGroupData[{
Cell[10759, 257, 135, 2, 31, "Input"],
Cell[10897, 261, 142, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11088, 269, 122, 1, 36, "Subsection"],
Cell[11213, 272, 5300, 168, 512, "Input"],
Cell[16516, 442, 1059, 23, 92, "Input"],
Cell[17578, 467, 1700, 39, 172, "Input"],
Cell[19281, 508, 522, 12, 52, "Input"],
Cell[19806, 522, 145, 2, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19988, 529, 258, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[20271, 536, 241, 3, 27, "Subsubsection"],
Cell[20515, 541, 13066, 275, 672, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[33618, 821, 270, 4, 23, "Subsubsection"],
Cell[33891, 827, 9396, 226, 431, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[43324, 1058, 272, 4, 23, "Subsubsection"],
Cell[43599, 1064, 9057, 221, 733, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[52693, 1290, 321, 5, 23, "Subsubsection"],
Cell[53017, 1297, 9227, 224, 732, "Input"]
}, Closed]],
Cell[62259, 1524, 270, 4, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[62554, 1532, 249, 3, 21, "Subsubsection"],
Cell[62806, 1537, 16639, 356, 812, "Input"],
Cell[CellGroupData[{
Cell[79470, 1897, 205, 3, 52, "Input"],
Cell[79678, 1902, 329, 5, 70, "Output"],
Cell[80010, 1909, 370, 6, 70, "Output"]
}, Open  ]],
Cell[80395, 1918, 9546, 231, 612, "Input"],
Cell[89944, 2151, 9628, 232, 612, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99609, 2388, 267, 4, 29, "Subsubsection"],
Cell[99879, 2394, 19178, 464, 1212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119094, 2863, 327, 5, 29, "Subsubsection"],
Cell[119424, 2870, 9382, 226, 733, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[128843, 3101, 373, 5, 23, "Subsubsection"],
Cell[129219, 3108, 9239, 223, 419, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[138507, 3337, 158, 2, 28, "Subsection"],
Cell[138668, 3341, 136, 3, 29, "Text"],
Cell[138807, 3346, 3816, 69, 92, "Input"],
Cell[142626, 3417, 657, 15, 52, "Input"],
Cell[143286, 3434, 881, 20, 52, "Input"],
Cell[CellGroupData[{
Cell[144192, 3458, 657, 9, 92, "Input"],
Cell[144852, 3469, 263, 5, 30, "Output"],
Cell[145118, 3476, 263, 5, 30, "Output"],
Cell[145384, 3483, 262, 5, 30, "Output"],
Cell[145649, 3490, 262, 5, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[145960, 3501, 159, 2, 36, "Subsection"],
Cell[146122, 3505, 130, 1, 29, "Text"],
Cell[146255, 3508, 945, 23, 31, "Input"],
Cell[147203, 3533, 901, 22, 92, "Input"],
Cell[148107, 3557, 416, 11, 52, "Input"],
Cell[148526, 3570, 526, 13, 52, "Input"],
Cell[149055, 3585, 416, 11, 52, "Input"],
Cell[149474, 3598, 392, 12, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149903, 3615, 108, 1, 36, "Subsection"],
Cell[150014, 3618, 71, 2, 31, "Input"],
Cell[150088, 3622, 685, 20, 52, "Input"],
Cell[150776, 3644, 157, 3, 31, "Input"],
Cell[150936, 3649, 584, 18, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[151557, 3672, 260, 3, 28, "Subsection"],
Cell[CellGroupData[{
Cell[151842, 3679, 1805, 27, 52, "Input"],
Cell[153650, 3708, 132, 3, 30, "Output"]
}, Open  ]],
Cell[153797, 3714, 445, 9, 31, "Input"],
Cell[154245, 3725, 219, 6, 31, "Input"],
Cell[154467, 3733, 1532, 41, 92, "Input"],
Cell[156002, 3776, 1484, 41, 112, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[157535, 3823, 97, 1, 41, "Section"],
Cell[CellGroupData[{
Cell[157657, 3828, 213, 3, 36, "Subsection"],
Cell[157873, 3833, 1335, 35, 92, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[159245, 3873, 169, 2, 28, "Subsection"],
Cell[159417, 3877, 3229, 84, 312, "Input"],
Cell[162649, 3963, 156, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[162830, 3971, 4967, 126, 212, "Input"],
Cell[167800, 4099, 3098, 76, 132, "Output"],
Cell[170901, 4177, 3111, 76, 132, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174049, 4258, 81, 1, 31, "Input"],
Cell[174133, 4261, 876, 18, 172, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175046, 4284, 192, 3, 31, "Input"],
Cell[175241, 4289, 896, 19, 172, "Output"]
}, Open  ]],
Cell[176152, 4311, 2773, 71, 132, "Input"],
Cell[CellGroupData[{
Cell[178950, 4386, 3662, 84, 112, "Input"],
Cell[182615, 4472, 2908, 68, 132, "Output"],
Cell[185526, 4542, 1269, 21, 172, "Output"]
}, Open  ]],
Cell[186810, 4566, 93, 1, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[186940, 4572, 162, 2, 28, "Subsection"],
Cell[187105, 4576, 41272, 1056, 1952, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228438, 5639, 181, 2, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[228644, 5645, 357, 5, 71, "Section"],
Cell[CellGroupData[{
Cell[229026, 5654, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[229151, 5659, 3045, 64, 92, "Input"],
Cell[232199, 5725, 1707, 27, 30, "Output"],
Cell[233909, 5754, 1689, 27, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235635, 5786, 1071, 28, 92, "Input"],
Cell[236709, 5816, 232, 3, 30, "Output"],
Cell[236944, 5821, 232, 3, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[237225, 5830, 175, 2, 36, "Subsection"],
Cell[237403, 5834, 167, 4, 31, "Input"],
Cell[237573, 5840, 4413, 104, 272, "Input"],
Cell[241989, 5946, 1796, 53, 132, "Input"],
Cell[243788, 6001, 1489, 32, 52, "Input"],
Cell[245280, 6035, 1799, 40, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[247116, 6080, 107, 1, 28, "Subsection"],
Cell[247226, 6083, 393, 9, 31, "Input"],
Cell[247622, 6094, 405, 9, 31, "Input"],
Cell[248030, 6105, 147, 3, 31, "Input"],
Cell[248180, 6110, 308, 8, 31, "Input"],
Cell[248491, 6120, 856, 24, 31, "Input"],
Cell[249350, 6146, 219, 4, 31, "Input"],
Cell[249572, 6152, 155, 3, 29, "Text"],
Cell[249730, 6157, 715, 16, 52, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[250494, 6179, 305, 4, 41, "Section"],
Cell[CellGroupData[{
Cell[250824, 6187, 125, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[250974, 6193, 3349, 67, 92, "Input"],
Cell[254326, 6262, 1287, 20, 30, "Output"],
Cell[255616, 6284, 1284, 20, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256937, 6309, 1347, 32, 92, "Input"],
Cell[258287, 6343, 539, 7, 30, "Output"],
Cell[258829, 6352, 537, 7, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[259415, 6365, 150, 2, 36, "Subsection"],
Cell[259568, 6369, 3262, 81, 232, "Input"],
Cell[262833, 6452, 925, 26, 72, "Input"],
Cell[263761, 6480, 449, 12, 31, "Input"],
Cell[264213, 6494, 2498, 63, 92, "Input"],
Cell[266714, 6559, 172, 3, 31, "Input"],
Cell[266889, 6564, 37, 0, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[266963, 6569, 107, 1, 28, "Subsection"],
Cell[CellGroupData[{
Cell[267095, 6574, 490, 10, 31, "Input"],
Cell[267588, 6586, 183, 2, 30, "Output"]
}, Open  ]],
Cell[267786, 6591, 458, 10, 31, "Input"],
Cell[268247, 6603, 909, 25, 31, "Input"],
Cell[CellGroupData[{
Cell[269181, 6632, 405, 9, 31, "Input"],
Cell[269589, 6643, 298, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269924, 6655, 484, 12, 31, "Input"],
Cell[270411, 6669, 259, 7, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[270731, 6683, 246, 3, 41, "Section"],
Cell[CellGroupData[{
Cell[271002, 6690, 174, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[271201, 6696, 6432, 166, 372, "Input"],
Cell[277636, 6864, 1240, 21, 30, "Output"],
Cell[278879, 6887, 976, 13, 30, "Output"],
Cell[279858, 6902, 1078, 17, 30, "Output"],
Cell[280939, 6921, 1236, 21, 30, "Output"],
Cell[282178, 6944, 977, 13, 30, "Output"],
Cell[283158, 6959, 1075, 17, 30, "Output"],
Cell[284236, 6978, 1238, 21, 33, "Output"],
Cell[285477, 7001, 981, 13, 30, "Output"],
Cell[286461, 7016, 1078, 17, 33, "Output"],
Cell[287542, 7035, 1235, 21, 30, "Output"],
Cell[288780, 7058, 980, 13, 30, "Output"],
Cell[289763, 7073, 1073, 17, 30, "Output"],
Cell[290839, 7092, 1239, 21, 30, "Output"],
Cell[292081, 7115, 979, 13, 30, "Output"],
Cell[293063, 7130, 1077, 17, 30, "Output"],
Cell[294143, 7149, 1237, 21, 30, "Output"],
Cell[295383, 7172, 979, 13, 30, "Output"],
Cell[296365, 7187, 1078, 17, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297480, 7209, 1274, 33, 132, "Input"],
Cell[298757, 7244, 368, 5, 30, "Output"],
Cell[299128, 7251, 368, 5, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[299545, 7262, 173, 2, 36, "Subsection"],
Cell[299721, 7266, 9272, 246, 432, "Input"],
Cell[CellGroupData[{
Cell[309018, 7516, 6452, 179, 252, "Input"],
Cell[315473, 7697, 395, 9, 30, "Output"],
Cell[315871, 7708, 377, 8, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[316297, 7722, 107, 1, 28, "Subsection"],
Cell[316407, 7725, 537, 11, 31, "Input"],
Cell[316947, 7738, 601, 11, 31, "Input"],
Cell[317551, 7751, 1129, 26, 31, "Input"],
Cell[318683, 7779, 1924, 52, 72, "Input"],
Cell[320610, 7833, 2335, 65, 72, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
